@@ -23,16 +23,19 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include <mysql/group_replication.h>
-
 #include "modules/adminapi/cluster/dissolve.h"
+
+#include <utility>
+
 #include "modules/adminapi/common/async_topology.h"
-#include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/provision.h"
 #include "mysqlshdk/include/shellcore/console.h"
+#include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
+#include "mysqlshdk/libs/utils/error.h"
+#include "mysqlshdk/libs/utils/logger.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
@@ -40,14 +43,13 @@ namespace mysqlsh {
 namespace dba {
 namespace cluster {
 
-Dissolve::Dissolve(const bool interactive,
-                   mysqlshdk::utils::nullable<bool> force,
+Dissolve::Dissolve(const bool interactive, std::optional<bool> force,
                    Cluster_impl *cluster)
     : m_interactive(interactive), m_force(force), m_cluster(cluster) {
   assert(cluster);
 }
 
-Dissolve::~Dissolve() {}
+Dissolve::~Dissolve() = default;
 
 void Dissolve::prompt_to_confirm_dissolve() const {
   // Show cluster description if not empty, to help user verify if he is
@@ -90,15 +92,19 @@ bool Dissolve::prompt_to_force_dissolve() const {
   return result;
 }
 
-void Dissolve::ensure_instance_reachable(const std::string &instance_address) {
+std::shared_ptr<Instance> Dissolve::ensure_instance_reachable(
+    const std::string &instance_address, const Instance_type instance_type) {
+  std::shared_ptr<Instance> ret_instance;
   try {
+    ret_instance = m_cluster->get_session_to_cluster_instance(instance_address);
+
     m_available_instances.emplace_back(
-        m_cluster->get_session_to_cluster_instance(instance_address));
+        std::make_pair(ret_instance, instance_type));
   } catch (const std::exception &err) {
     // instance not reachable
     auto console = mysqlsh::current_console();
     // Handle use of 'force' option.
-    if (m_force.is_null() || *m_force == false) {
+    if (!m_force.has_value() || !m_force.value()) {
       console->print_error(
           "Unable to connect to instance '" + instance_address +
           "'. Please verify connection credentials and make sure the "
@@ -107,7 +113,7 @@ void Dissolve::ensure_instance_reachable(const std::string &instance_address) {
       // In interactive mode and 'force' option not used, ask user to
       // continue with the operation.
       bool continue_dissolve = false;
-      if (m_interactive && m_force.is_null()) {
+      if (m_interactive && !m_force.has_value()) {
         continue_dissolve = prompt_to_force_dissolve();
       }
 
@@ -128,6 +134,8 @@ void Dissolve::ensure_instance_reachable(const std::string &instance_address) {
       console->print_info();
     }
   }
+
+  return ret_instance;
 }
 
 void Dissolve::ensure_transactions_sync() {
@@ -136,18 +144,20 @@ void Dissolve::ensure_transactions_sync() {
   for (const auto &instance : m_available_instances) {
     try {
       auto console = mysqlsh::current_console();
-      console->print_info("* Waiting for instance '" + instance->descr() +
+      console->print_info("* Waiting for instance '" + instance.first->descr() +
                           "' to apply received transactions...");
+
       m_cluster->sync_transactions(
-          *instance, mysqlshdk::gr::k_gr_applier_channel,
+          *instance.first, instance.second,
           current_shell_options()->get().dba_gtid_wait_timeout, true);
     } catch (const std::exception &err) {
       std::string instance_address =
-          (*instance).get_connection_options().as_uri(
-              mysqlshdk::db::uri::formats::only_transport());
+          (*instance.first)
+              .get_connection_options()
+              .as_uri(mysqlshdk::db::uri::formats::only_transport());
 
       // Handle use of 'force' option.
-      if (m_force.is_null() || *m_force == false) {
+      if (!m_force.has_value() || !m_force.value()) {
         mysqlsh::current_console()->print_error(
             "The instance '" + instance_address +
             "' was unable to catch up with cluster transactions. There might "
@@ -162,7 +172,7 @@ void Dissolve::ensure_transactions_sync() {
         // In interactive mode and 'force' option not used, ask user to
         // continue with the operation.
         bool continue_dissolve = false;
-        if (m_interactive && m_force.is_null()) {
+        if (m_interactive && !m_force.has_value()) {
           continue_dissolve = prompt_to_force_dissolve();
         }
 
@@ -190,7 +200,7 @@ void Dissolve::handle_unavailable_instances(const std::string &instance_address,
                                             const std::string &instance_state) {
   auto console = mysqlsh::current_console();
 
-  if (m_force.is_null() || *m_force == false) {
+  if (!m_force.has_value() || !m_force.value()) {
     // Issue an error if 'force' option is not used or false.
     std::string message =
         "The instance '" + instance_address +
@@ -198,7 +208,7 @@ void Dissolve::handle_unavailable_instances(const std::string &instance_address,
         "' state. Please bring the instance back ONLINE and try to "
         "dissolve the cluster again. If the instance is permanently not "
         "reachable, ";
-    if (m_interactive && m_force.is_null()) {
+    if (m_interactive && !m_force.has_value()) {
       message +=
           "then you can choose to proceed with the operation and only "
           "remove the instance from the Cluster Metadata.";
@@ -214,7 +224,7 @@ void Dissolve::handle_unavailable_instances(const std::string &instance_address,
     // In interactive mode and 'force' option not used, ask user to
     // continue with the operation.
     bool continue_dissolve = false;
-    if (m_interactive && m_force.is_null()) {
+    if (m_interactive && !m_force.has_value()) {
       continue_dissolve = prompt_to_force_dissolve();
     }
 
@@ -284,24 +294,53 @@ void Dissolve::prepare() {
   };
 
   // Get all cluster instances, including state information.
-  std::vector<Instance_metadata> instance_defs = m_cluster->get_instances();
+  std::vector<Instance_metadata> instance_defs = m_cluster->get_all_instances();
   // Check if instances can be dissolved. More specifically, verify if their
   // state is valid, if they are reachable (i.e., able to connect to them).
   // Also determine if instance removal can be skipped, according to 'force'
   // option and user prompts.
   for (const auto &instance_def : instance_defs) {
-    mysqlshdk::gr::Member_state state;
-    bool is_primary;
-    std::tie(state, is_primary) = get_member_state(instance_def.uuid);
+    if (instance_def.instance_type != Instance_type::READ_REPLICA) {
+      mysqlshdk::gr::Member_state state;
+      bool is_primary;
+      std::tie(state, is_primary) = get_member_state(instance_def.uuid);
 
-    if (state == mysqlshdk::gr::Member_state::ONLINE ||
-        state == mysqlshdk::gr::Member_state::RECOVERING) {
-      // Verify if active instances are reachable.
-      ensure_instance_reachable(instance_def.endpoint);
+      if (state == mysqlshdk::gr::Member_state::ONLINE ||
+          state == mysqlshdk::gr::Member_state::RECOVERING) {
+        // Verify if active instances are reachable.
+        ensure_instance_reachable(instance_def.endpoint,
+                                  instance_def.instance_type);
+      } else {
+        // Handle not active instances, determining if they can be skipped.
+        handle_unavailable_instances(instance_def.endpoint,
+                                     mysqlshdk::gr::to_string(state));
+      }
     } else {
-      // Handle not active instances, determining if they can be skipped.
-      handle_unavailable_instances(instance_def.endpoint,
-                                   mysqlshdk::gr::to_string(state));
+      // Check Read-Replicas to check if reachable
+      try {
+        auto rr_instance = ensure_instance_reachable(
+            instance_def.endpoint, instance_def.instance_type);
+
+        // Get the status
+        if (rr_instance) {
+          auto status = mysqlshdk::mysql::get_read_replica_status(*rr_instance);
+
+          if (status != mysqlshdk::mysql::Read_replica_status::ONLINE) {
+            // Handle unreachable read-replica to determine if can be skipped
+            handle_unavailable_instances(instance_def.endpoint,
+                                         to_string(status));
+          }
+        }
+      } catch (const mysqlshdk::db::Error &) {
+        log_info("Unable to connect to '%s'", instance_def.endpoint.c_str());
+
+        // Handle unreachable read-replica to determine if can be skipped
+        handle_unavailable_instances(
+            instance_def.endpoint,
+            to_string(mysqlshdk::mysql::Read_replica_status::UNREACHABLE));
+      } catch (const shcore::Error &) {
+        throw;
+      }
     }
   }
 
@@ -311,7 +350,7 @@ void Dissolve::prepare() {
   ensure_transactions_sync();
 
   // If user decided to skip all instance with errors then assume force=true.
-  if (m_force.is_null() &&
+  if (!m_force.has_value() &&
       (!m_skipped_instances.empty() || !m_sync_error_instances.empty())) {
     m_force = true;
   }
@@ -321,52 +360,6 @@ void Dissolve::prepare() {
                               Precondition_checker::k_min_cs_version;
 }
 
-void Dissolve::remove_instance(const std::string &instance_address,
-                               const std::size_t instance_index) {
-  try {
-    // Stop Group Replication and reset (persist) GR variables.
-    mysqlsh::dba::leave_cluster(*m_available_instances[instance_index],
-                                m_supports_member_actions);
-
-    // Reset the ClusterSet replication channel
-    //
-    // NOTE: It's not possible to dissolve a Cluster that belongs to a
-    // ClusterSet, the Cluster needs to be removed from the ClusterSet (which
-    // will ensure the replication channel is reset among other
-    // reconfiguration). However, there is a remote possibility of a failed
-    // create_replica_cluster() to leave a dangling Cluster that is fully
-    // set up but not part of the ClusterSet yet. Users should be able
-    // to dissolve() that Cluster, but if the replication channel is present
-    // the command won't stop/reset it. That leftover will hit the precondition
-    // checks for reusing the ex-members of that Cluster (have no replication
-    // channels configured). For that reason, we should aim to clean as much as
-    // possible, and considering that the remove_channel() function is a no-op
-    // if the channel doesn't exist, we always call it.
-    remove_channel(m_available_instances[instance_index].get(),
-                   k_clusterset_async_channel_name, false);
-  } catch (const std::exception &err) {
-    auto console = mysqlsh::current_console();
-
-    // Skip error if force=true otherwise issue an error.
-    if (m_force.is_null() || *m_force == false) {
-      console->print_error("Unable to remove instance '" + instance_address +
-                           "' from the cluster.");
-      throw shcore::Exception::runtime_error(err.what());
-    } else {
-      m_skipped_instances.push_back(instance_address);
-      log_error("Instance '%s' failed to leave the cluster: %s",
-                instance_address.c_str(), err.what());
-      console->print_warning(
-          "An error occurred when trying to remove instance '" +
-          instance_address +
-          "' from the cluster. The instance might have been left active "
-          "and in an inconsistent state, requiring manual action to "
-          "fully dissolve the cluster.");
-      console->print_info();
-    }
-  }
-}
-
 shcore::Value Dissolve::execute() {
   std::shared_ptr<MetadataStorage> metadata = m_cluster->get_metadata_storage();
   auto console = mysqlsh::current_console();
@@ -374,9 +367,10 @@ shcore::Value Dissolve::execute() {
   console->print_info("* Dissolving the Cluster...");
 
   // Disable super_read_only mode if it is enabled.
-  bool super_read_only = m_cluster->get_cluster_server()->get_sysvar_bool(
-      "super_read_only", false);
-  if (super_read_only) {
+
+  if (auto sro = m_cluster->get_cluster_server()->get_sysvar_bool(
+          "super_read_only", false);
+      sro) {
     log_info(
         "Disabling super_read_only mode on instance '%s' to run dissolve().",
         m_cluster->get_cluster_server()->descr().c_str());
@@ -385,8 +379,8 @@ shcore::Value Dissolve::execute() {
 
   // Remove replication accounts used for recovery of GR and ClusterSet
   // replication accounts
-  // Note: This operation MUST be performed before leave-cluster to ensure that
-  // all changed are propagated to the online instances.
+  // Note: This operation MUST be performed before leave-cluster to ensure
+  // that all changed are propagated to the online instances.
   m_cluster->wipe_all_replication_users();
 
   // Drop the metadata schema
@@ -395,23 +389,23 @@ shcore::Value Dissolve::execute() {
   // We must stop GR on the online instances only, otherwise we'll
   // get connection failures to the (MISSING) instances
   // BUG#26001653.
-  for (std::size_t i = 0; i < m_available_instances.size(); i++) {
-    auto &instance = *m_available_instances[i];
+  for (const auto &instance : m_available_instances) {
+    auto instance_type = instance.second;
+    auto instance_ptr = instance.first;
 
-    std::string instance_address = instance.get_connection_options().as_uri(
-        mysqlshdk::db::uri::formats::only_transport());
+    std::string instance_address = instance_ptr->descr();
 
     // JOB: Sync transactions with the cluster.
     try {
       // Catch-up with all cluster transaction to ensure cluster metadata is
       // removed on the instance.
-      console->print_info("* Waiting for instance '" + instance.descr() +
+      console->print_info("* Waiting for instance '" + instance_address +
                           "' to apply received transactions...");
 
       // We only need to apply received transactions, since any transactions
       // certified by the group will have been received
       m_cluster->sync_transactions(
-          instance, mysqlshdk::gr::k_gr_applier_channel,
+          *instance_ptr, instance_type,
           current_shell_options()->get().dba_gtid_wait_timeout, true);
 
       // Remove instance from list of instance with sync error in case it
@@ -424,36 +418,107 @@ shcore::Value Dissolve::execute() {
           m_sync_error_instances.end());
     } catch (const std::exception &err) {
       // Skip error if force=true otherwise issue an error.
-      if (m_force.is_null() || *m_force == false) {
+      if (!m_force.has_value() || !m_force.value()) {
         console->print_error(
             "The instance '" + instance_address +
             "' was unable to catch up with cluster transactions. There might "
             "be too many transactions to apply or some replication error.");
         throw;
-      } else {
-        // Only add to list of instance with sync error if not already there.
-        if (std::find(m_sync_error_instances.begin(),
-                      m_sync_error_instances.end(),
-                      instance_address) == m_sync_error_instances.end()) {
-          m_sync_error_instances.push_back(instance_address);
-        }
-
-        log_error(
-            "Instance '%s' was unable to catch up with cluster transactions: "
-            "%s",
-            instance_address.c_str(), err.what());
-        console->print_warning(
-            "An error occurred when trying to catch up with cluster "
-            "transactions and instance '" +
-            instance_address +
-            "' might have been left in an inconsistent state that will lead "
-            "to errors if it is reused.");
-        console->print_info();
       }
+
+      // Only add to list of instance with sync error if not already there.
+      if (std::find(m_sync_error_instances.begin(),
+                    m_sync_error_instances.end(),
+                    instance_address) == m_sync_error_instances.end()) {
+        m_sync_error_instances.push_back(instance_address);
+      }
+
+      log_error(
+          "Instance '%s' was unable to catch up with cluster transactions: %s",
+          instance_address.c_str(), err.what());
+      console->print_warning(
+          "An error occurred when trying to catch up with cluster transactions "
+          "and instance '" +
+          instance_address +
+          "' might have been left in an inconsistent state that will lead to "
+          "errors if it is reused.");
+      console->print_info();
     }
 
-    // JOB: Remove the instance from the cluster (Stop GR)
-    remove_instance(instance_address, i);
+    // JOB: Remove the instance from the cluster
+    switch (instance_type) {
+      case Instance_type::NONE:
+      case Instance_type::GROUP_MEMBER: {
+        try {
+          // Stop Group Replication and reset (persist) GR variables.
+          mysqlsh::dba::leave_cluster(*instance_ptr, m_supports_member_actions);
+
+          // Reset the ClusterSet replication channel
+          //
+          // NOTE: It's not possible to dissolve a Cluster that belongs to a
+          // ClusterSet, the Cluster needs to be removed from the ClusterSet
+          // (which will ensure the replication channel is reset among other
+          // reconfiguration). However, there is a remote possibility of a
+          // failed create_replica_cluster() to leave a dangling Cluster that
+          // is fully set up but not part of the ClusterSet yet. Users should
+          // be able to dissolve() that Cluster, but if the replication channel
+          // is present the command won't stop/reset it. That leftover will hit
+          // the precondition checks for reusing the ex-members of that Cluster
+          // (have no replication channels configured). For that reason, we
+          // should aim to clean as much as possible, and considering that the
+          // remove_channel() function is a no-op if the channel doesn't exist,
+          // we always call it.
+          remove_channel(*instance_ptr, k_clusterset_async_channel_name, false);
+        } catch (const std::exception &err) {
+          // Skip error if force=true otherwise issue an error.
+          if (!m_force.has_value() || !m_force.value()) {
+            console->print_error("Unable to remove instance '" +
+                                 instance_address + "' from the cluster.");
+            throw shcore::Exception::runtime_error(err.what());
+          } else {
+            m_skipped_instances.push_back(instance_address);
+            log_error("Instance '%s' failed to leave the cluster: %s",
+                      instance_address.c_str(), err.what());
+            console->print_warning(
+                "An error occurred when trying to remove instance '" +
+                instance_address +
+                "' from the cluster. The instance might have been left active "
+                "and in an inconsistent state, requiring manual action to "
+                "fully dissolve the cluster.");
+            console->print_info();
+          }
+        }
+
+        break;
+      }
+      case Instance_type::READ_REPLICA: {
+        console->print_info("* Removing Read-Replica '" + instance_address +
+                            "' from the cluster...");
+
+        // Remove the async channel
+        remove_channel(*instance_ptr, k_read_replica_async_channel_name, false);
+
+        try {
+          log_info("Disabling automatic failover management at %s",
+                   instance_ptr->descr().c_str());
+
+          reset_managed_connection_failover(*instance_ptr, false);
+        } catch (...) {
+          log_error("Error disabling automatic failover at %s: %s",
+                    instance_address.c_str(),
+                    format_active_exception().c_str());
+          console->print_warning(
+              "An error occurred when trying to disable automatic failover on "
+              "Read-Replica at '" +
+              instance_address + "'");
+          console->print_info();
+        }
+
+        break;
+      }
+      case Instance_type::ASYNC_MEMBER:
+        break;
+    }
   }
 
   // Disconnect all internal sessions
@@ -524,7 +589,7 @@ void Dissolve::rollback() {
 void Dissolve::finish() {
   // Close all sessions to available instances.
   for (const auto &instance : m_available_instances) {
-    instance->close_session();
+    instance.first->close_session();
   }
 
   // Reset all auxiliary (temporary) data used for the operation execution.
