@@ -28,18 +28,19 @@
 #include <algorithm>
 #include <iterator>
 #include <set>
-#include <utility>
 
 #include "adminapi/common/common.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/preconditions.h"
+#include "modules/adminapi/common/server_features.h"
 #include "modules/adminapi/common/validations.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/config/config.h"
-#include "mysqlshdk/libs/utils/utils_general.h"
+#include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "utils/utils_string.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -117,7 +118,7 @@ void Rescan::ensure_unavailable_instances_not_auto_rejoining(
     try {
       auto instance = Instance::connect_raw(instance_conn_opt);
       is_rejoining = mysqlshdk::gr::is_running_gr_auto_rejoin(*instance);
-    } catch (const std::exception &e) {
+    } catch (const std::exception &) {
       // if you cant connect to the instance then we assume it really is offline
       // or unreachable and it is not auto-rejoining
     }
@@ -136,8 +137,9 @@ void Rescan::ensure_unavailable_instances_not_auto_rejoining(
 std::vector<std::string> Rescan::detect_invalid_members(
     const std::vector<mysqlshdk::db::Connection_options> &instances_list,
     bool is_active) {
-  std::vector<std::string> invalid_instances;
+  std::shared_ptr<Instance> cluster_instance = m_cluster->get_cluster_server();
 
+  std::vector<std::string> invalid_instances;
   for (const auto &cnx_opt : instances_list) {
     std::string instance_address =
         cnx_opt.as_uri(mysqlshdk::db::uri::formats::only_transport());
@@ -147,9 +149,6 @@ std::vector<std::string> Rescan::detect_invalid_members(
         "Checking if the instance '%s' is %san active member of the group.",
         instance_address.c_str(), check_type);
 
-    std::shared_ptr<Instance> cluster_instance =
-        m_cluster->get_cluster_server();
-
     if (mysqlshdk::gr::is_active_member(*cluster_instance, cnx_opt.get_host(),
                                         cnx_opt.get_port()) != is_active) {
       invalid_instances.push_back(instance_address);
@@ -225,7 +224,7 @@ void Rescan::prepare() {
                                     Precondition_checker::k_min_cs_version;
 
   // Validate the usage of the option 'updateViewChangeUuid'
-  if (m_options.update_view_change_uuid.get_safe() &&
+  if (m_options.update_view_change_uuid.value_or(false) &&
       !m_is_view_change_uuid_supported) {
     throw shcore::Exception::argument_error(
         "The Cluster cannot be configured to use "
@@ -237,7 +236,7 @@ void Rescan::check_mismatched_hostnames_addresses(
     shcore::Array_t instances) const {
   m_cluster->execute_in_members(
       [&instances](const std::shared_ptr<Instance> &instance,
-                   const Instance_md_and_gr_member &info) {
+                   const Cluster_impl::Instance_md_and_gr_member &info) {
         // skip members that are already in the update list
         for (const auto &i : *instances) {
           if (i.as_map()->get_string("member_id") == instance->get_uuid())
@@ -247,7 +246,7 @@ void Rescan::check_mismatched_hostnames_addresses(
         bool grendpoint_valid = true;
         try {
           mysqlshdk::utils::split_host_and_port(info.first.grendpoint);
-        } catch (const std::invalid_argument &e) {
+        } catch (const std::invalid_argument &) {
           log_debug("Unable to parse endpoint: %s",
                     info.first.grendpoint.c_str());
           grendpoint_valid = false;
@@ -325,9 +324,8 @@ void Rescan::check_mismatched_hostnames_addresses(
 
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 bool Rescan::is_clusterset_metadata_consistent() {
@@ -418,17 +416,16 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() {
         shcore::Value(instance.member_id);
     (*newly_discovered_instance)["name"] = shcore::Value::Null();
 
-    std::string instance_address =
-        instance.host + ":" + std::to_string(instance.port);
-
-    (*newly_discovered_instance)["host"] = shcore::Value(instance_address);
+    (*newly_discovered_instance)["host"] =
+        shcore::Value(mysqlshdk::utils::make_host_and_port(
+            instance.host, static_cast<uint16_t>(instance.port)));
 
     if (!instance.version.empty()) {
       (*newly_discovered_instance)["version"] = shcore::Value(instance.version);
     }
 
     newly_discovered_instances->push_back(
-        shcore::Value(newly_discovered_instance));
+        shcore::Value(std::move(newly_discovered_instance)));
   }
 
   std::sort(newly_discovered_instances->begin(),
@@ -497,16 +494,17 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() {
 
   // Get the primary UUID value to determine GR mode:
   // UUID (not empty) -> single-primary or "" (empty) -> multi-primary
-  std::string gr_primary_uuid = mysqlshdk::gr::get_group_primary_uuid(
-      *m_cluster->get_cluster_server(), nullptr);
+  bool single_primary;
+  mysqlshdk::gr::get_group_primary_uuid(*m_cluster->get_cluster_server(),
+                                        &single_primary);
 
   // Check if the topology mode match and report needed change in the metadata.
-  if (gr_primary_uuid.empty() &&
+  if (!single_primary &&
       metadata_topology_mode == mysqlshdk::gr::Topology_mode::SINGLE_PRIMARY) {
     // Topology mode need to be changed to multi-primary on the metadata.
     (*cluster_map)["newTopologyMode"] = shcore::Value(
         mysqlshdk::gr::to_string(mysqlshdk::gr::Topology_mode::MULTI_PRIMARY));
-  } else if (!gr_primary_uuid.empty() &&
+  } else if (single_primary &&
              metadata_topology_mode ==
                  mysqlshdk::gr::Topology_mode::MULTI_PRIMARY) {
     // Topology mode need to be changed to single-primary on the metadata.
@@ -567,7 +565,7 @@ void Rescan::add_instance_to_metadata(
         m_cluster->get_cluster_server()->get_connection_options());
   }
 
-  m_cluster->add_metadata_for_instance(cnx_opts);
+  m_cluster->add_metadata_for_instance(cnx_opts, Instance_type::GROUP_MEMBER);
 
   console->print_info(
       "The instance '" +
@@ -594,8 +592,7 @@ void Rescan::update_metadata_for_instance(
 
 void Rescan::remove_instance_from_metadata(
     const std::string &instance_address) {
-  mysqlshdk::db::Connection_options instance_cnx_opts =
-      shcore::get_connection_options(instance_address, false);
+  mysqlshdk::db::Connection_options instance_cnx_opts(instance_address);
 
   auto console = mysqlsh::current_console();
   console->print_info("Removing instance from the cluster metadata...");
@@ -662,13 +659,11 @@ void Rescan::add_metadata_for_instances(
       instance_cnx_opts = *list_iter;
       m_options.add_instances_list.erase(list_iter);
     } else if (m_options.auto_add) {
-      instance_cnx_opts =
-          shcore::get_connection_options(instance_address, false);
-    } else if (m_options.interactive()) {
+      instance_cnx_opts = mysqlshdk::db::Connection_options(instance_address);
+    } else if (current_shell_options()->get().wizards) {
       if (console->confirm("Would you like to add it to the cluster metadata?",
                            Prompt_answer::YES) == Prompt_answer::YES) {
-        instance_cnx_opts =
-            shcore::get_connection_options(instance_address, false);
+        instance_cnx_opts = mysqlshdk::db::Connection_options(instance_address);
       }
     }
 
@@ -701,7 +696,7 @@ void Rescan::remove_metadata_for_instances(
     } else if (m_options.auto_remove) {
       // Remove instance automatically if "auto" was used.
       remove_instance_from_metadata(instance_address);
-    } else if (m_options.interactive()) {
+    } else if (current_shell_options()->get().wizards) {
       console->print_info(
           "The instance is either offline or left the HA group. You can try "
           "to add it to the cluster again with the cluster.rejoinInstance('" +
@@ -771,7 +766,7 @@ void Rescan::update_metadata_for_instances(
 
     // Decide to add/remove instance based on given operation options.
     auto instance_cnx_opts =
-        shcore::get_connection_options(instance_address, false);
+        mysqlshdk::db::Connection_options(instance_address);
 
     update_metadata_for_instance(instance_cnx_opts,
                                  instance_map->get_uint("id"), label);
@@ -854,7 +849,7 @@ void Rescan::ensure_view_change_uuid_set() {
           "group_replication_view_change_uuid...");
 
       // Generate a value for group_replication_view_change_uuid
-      view_change_uuid = mysqlshdk::gr::generate_uuid(*cluster_instance);
+      view_change_uuid = cluster_instance->generate_uuid();
 
       // Get the Cluster Config Object
       // This ensures the config is set on ONLINE || RECOVERING members
@@ -954,7 +949,7 @@ void Rescan::ensure_transaction_size_limit_consistency() {
   m_cluster->execute_in_members(
       [cluster_transaction_size_limit](
           const std::shared_ptr<Instance> &instance,
-          const Instance_md_and_gr_member &info) {
+          const Cluster_impl::Instance_md_and_gr_member &info) {
         if (info.second.state != mysqlshdk::gr::Member_state::RECOVERING &&
             info.second.state != mysqlshdk::gr::Member_state::UNREACHABLE) {
           // Get the instance's value for transaction_size_limit
@@ -988,15 +983,14 @@ void Rescan::ensure_transaction_size_limit_consistency() {
         }
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 void Rescan::ensure_recovery_accounts_match() {
   m_cluster->execute_in_members(
       [this](const std::shared_ptr<Instance> &instance,
-             const Instance_md_and_gr_member &info) {
+             const Cluster_impl::Instance_md_and_gr_member &info) {
         switch (info.second.state) {
           case mysqlshdk::gr::Member_state::RECOVERING:
           case mysqlshdk::gr::Member_state::UNREACHABLE:
@@ -1016,11 +1010,10 @@ void Rescan::ensure_recovery_accounts_match() {
             recovery_user, mysqlshdk::gr::k_group_recovery_old_user_prefix);
 
         // Generate the recovery account string for this instance
-        std::string recovery_user_generated =
-            Cluster_impl::make_replication_user_name(
-                instance->get_server_id(),
-                old_prefix ? mysqlshdk::gr::k_group_recovery_old_user_prefix
-                           : mysqlshdk::gr::k_group_recovery_user_prefix);
+        auto recovery_user_generated = Cluster_impl::make_replication_user_name(
+            instance->get_server_id(),
+            old_prefix ? mysqlshdk::gr::k_group_recovery_old_user_prefix
+                       : mysqlshdk::gr::k_group_recovery_user_prefix);
 
         // If the recovery user being used is different than the generated one
         // it means the instance was added using clone as the recovery method
@@ -1031,7 +1024,6 @@ void Rescan::ensure_recovery_accounts_match() {
         if (recovery_user == recovery_user_generated) return true;
 
         auto console = mysqlsh::current_console();
-
         console->print_info(shcore::str_format(
             "Fixing incorrect recovery account '%s' in instance '%s'",
             recovery_user.c_str(), instance->descr().c_str()));
@@ -1050,8 +1042,8 @@ void Rescan::ensure_recovery_accounts_match() {
               m_cluster->query_cluster_instance_auth_cert_subject(*instance));
 
           m_cluster->get_metadata_storage()->update_instance_repl_account(
-              instance->get_uuid(), Cluster_type::GROUP_REPLICATION, new_user,
-              new_host);
+              instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+              Replica_type::GROUP_MEMBER, new_user, new_host);
 
           console->print_warning(shcore::str_format(
               "A new recovery user for instance '%s' was created, which leaves "
@@ -1067,14 +1059,14 @@ void Rescan::ensure_recovery_accounts_match() {
 
           m_cluster->get_metadata_storage()->update_instance_repl_account(
               instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
-              recovery_user_generated, recovery_user_hosts.front());
+              Replica_type::GROUP_MEMBER, recovery_user_generated,
+              recovery_user_hosts.front());
         }
 
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 shcore::Value Rescan::execute() {
@@ -1095,7 +1087,7 @@ shcore::Value Rescan::execute() {
   }
 
   // Print warning about not used instances in addInstances.
-  {
+  if (!m_options.add_instances_list.empty()) {
     std::vector<std::string> not_used_add_instances;
     not_used_add_instances.reserve(m_options.add_instances_list.size());
 
@@ -1115,12 +1107,8 @@ shcore::Value Rescan::execute() {
   }
 
   // Check if there are missing instances
-  std::shared_ptr<shcore::Value::Array_type> missing_instances;
-
   if (result->has_key("unavailableInstances")) {
-    missing_instances = result->get_array("unavailableInstances");
-
-    remove_metadata_for_instances(missing_instances);
+    remove_metadata_for_instances(result->get_array("unavailableInstances"));
   }
 
   if (result->has_key("updatedInstances")) {
@@ -1128,7 +1116,7 @@ shcore::Value Rescan::execute() {
   }
 
   // Fix all missing recovery accounts from metadata.
-  m_cluster->ensure_metadata_has_recovery_accounts();
+  m_cluster->ensure_metadata_has_recovery_accounts(true);
 
   // This calls ensures all of the instances have server_id as instance
   // attribute, including the case were rescan is executed and no new/updated
@@ -1138,19 +1126,28 @@ shcore::Value Rescan::execute() {
   // Check if group_replication_view_change_uuid is set on the Cluster and all
   // of its members when running MySQL >= 8.0.27. Also verify the Metadata
   // consistency regarding group_replication_view_change_uuid when already in
-  // use
+  // use.
+  // Skip if running MySQL >= 8.3.0, since the option is no longer needed.
+
   if (m_is_view_change_uuid_supported) {
-    auto view_change_uuid = m_cluster->get_primary_master()->get_sysvar_string(
+    auto view_change_uuid = m_cluster->get_cluster_server()->get_sysvar_string(
         "group_replication_view_change_uuid", "");
 
     if (view_change_uuid == "AUTOMATIC") {
-      if (m_options.update_view_change_uuid.is_null()) {
+      auto lowest_version_cluster = m_cluster->get_lowest_instance_version();
+
+      DBUG_EXECUTE_IF("dba_view_change_uuid_needed", {
+        lowest_version_cluster = mysqlshdk::utils::Version(8, 1, 0);
+      });
+
+      if (!m_options.update_view_change_uuid.has_value() &&
+          lowest_version_cluster < k_view_change_uuid_deprecated) {
         console->print_note(
             "The Cluster is not configured to use "
             "'group_replication_view_change_uuid', which is required "
             "for InnoDB ClusterSet. Configuring it requires a full Cluster "
             "reboot.");
-        if (m_options.interactive()) {
+        if (current_shell_options()->get().wizards) {
           // Prompt the user to update the View Change UUID
           if (console->confirm(
                   "Would you like 'group_replication_view_change_uuid' to be "
@@ -1163,7 +1160,7 @@ shcore::Value Rescan::execute() {
               "Use the 'updateViewChangeUuid' option to generate and "
               "configure a value for the Cluster.");
         }
-      } else if (m_options.update_view_change_uuid.get_safe()) {
+      } else if (m_options.update_view_change_uuid.value_or(false)) {
         ensure_view_change_uuid_set();
       }
     } else {
@@ -1181,7 +1178,7 @@ shcore::Value Rescan::execute() {
   ensure_transaction_size_limit_consistency();
 
   // Print warning about not used instances in removeInstances.
-  {
+  if (!m_options.remove_instances_list.empty()) {
     std::vector<std::string> not_used_remove_instances;
     not_used_remove_instances.reserve(m_options.remove_instances_list.size());
 
@@ -1206,7 +1203,7 @@ shcore::Value Rescan::execute() {
   //       the auto-increment settings on all of them.
   if (result->has_key("newTopologyMode") &&
       !result->is_null("newTopologyMode")) {
-    std::string new_topology_mode = result->get_string("newTopologyMode");
+    auto new_topology_mode = result->get_string("newTopologyMode");
 
     if (!new_topology_mode.empty()) {
       console->print_note("The topology mode of the cluster changed to '" +
@@ -1254,7 +1251,7 @@ shcore::Value Rescan::execute() {
           "Metadata inconsistencies detected, possibly due to one or more "
           "failed commands. Please review the topology status before "
           "proceeding.");
-      if (m_options.interactive()) {
+      if (current_shell_options()->get().wizards) {
         // Prompt the user to confirm the action
         if (console->confirm(
                 "The invalid Cluster(s) listed above will be removed from the "
