@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -27,6 +29,7 @@
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -115,16 +118,13 @@ struct Privilege_versions {
 // Global privs needed for managing cluster instances
 // BUG#29743910: clusterAdmin needs SELECT on *.* for tables compliance check.
 // BUG#30339460: SYSTEM_VARIABLES_ADMIN and PERSIST_RO_VARIABLES_ADMIN
-//               privileges needed to change Global system variables for 8.0
-//               servers (not for 5.7).
+//               privileges needed to change Global system variables.
 const std::vector<Privilege_versions> k_admin_global_privileges{
     {"RELOAD", Version(), Version()},
     {"SHUTDOWN", Version(), Version()},
     {"PROCESS", Version(), Version()},
     {"FILE", Version(), Version()},
     {"SELECT", Version(), Version()},
-    {"SUPER", Version(5, 7, 0),
-     Version(5, 7, 9999)},  // SUPER is exclusive of 5.7
     {"REPLICATION SLAVE", Version(), Version()},
     {"REPLICATION CLIENT", Version(), Version()},
     {"CREATE USER", Version(), Version()},
@@ -181,7 +181,7 @@ const std::map<std::string, std::set<std::string>> k_admin_schema_grants{
 // (global_status, session_status, variables_info), but they do not require a
 // specific privilege (enabled by default).
 // See:
-// https://dev.mysql.com/doc/refman/8.0/en/performance-schema-system-variable-tables.html
+// https://dev.mysql.com/doc/refman/en/performance-schema-system-variable-tables.html
 const std::map<std::string, std::map<std::string, std::set<std::string>>>
     k_admin_table_grants{};
 
@@ -225,8 +225,15 @@ const std::map<std::string, std::map<std::string, std::set<std::string>>>
                             {"replication_group_member_stats", {"SELECT"}},
                             {"global_variables", {"SELECT"}}}},
                           {"mysql_innodb_cluster_metadata",
-                           {{"routers", {"INSERT", "UPDATE", "DELETE"}},
-                            {"v2_routers", {"INSERT", "UPDATE", "DELETE"}}}}};
+                           {
+                               {"routers", {"INSERT", "UPDATE", "DELETE"}},
+                               {"v2_routers", {"INSERT", "UPDATE", "DELETE"}},
+                               {"clusters", {"UPDATE"}},
+                               {"clustersets", {"UPDATE"}},
+                               {"v2_gr_clusters", {"UPDATE"}},
+                               {"v2_ar_clusters", {"UPDATE"}},
+                               {"v2_cs_clustersets", {"UPDATE"}},
+                           }}};
 
 std::string create_grant(const std::string &username,
                          const std::set<std::string> &privileges,
@@ -362,10 +369,19 @@ std::vector<std::string> create_router_grants(
   // tables on older metadata version from the list of tables
   std::map<std::string, std::map<std::string, std::set<std::string>>>
       router_table_grants = k_router_table_grants;
-  // For old metadata versions, there is no v2_routers table, so drop it
-  // from table_grants
-  if (metadata_version <= mysqlshdk::utils::Version(1, 0, 1)) {
+  // For old metadata versions, there is no v2_routers, v2_gr_clusters,
+  // v2_ar_clusters, and v2_cs_clustersets tables, so drop them from
+  // table_grants
+  if (metadata_version <= mysqlshdk::utils::Version(2, 0, 0)) {
     router_table_grants["mysql_innodb_cluster_metadata"].erase("v2_routers");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_gr_clusters");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_ar_clusters");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_cs_clustersets");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase("clustersets");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase("clusters");
   }
 
   // privileges for tables
