@@ -38,6 +38,9 @@
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/instance_pool.h"
 #include "modules/adminapi/common/metadata_management_mysql.h"
+#include "modules/adminapi/common/router_options.h"
+#include "mysqlshdk/include/scripting/types.h"
+#include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/undo.h"
 #include "mysqlshdk/libs/mysql/utils.h"
@@ -50,8 +53,13 @@ inline constexpr const char *kNotifyClusterSetPrimaryChanged =
 
 inline constexpr const char *kNotifyDataClusterSetId = "CLUSTER_SET_ID";
 
+enum class Instance_type { GROUP_MEMBER, ASYNC_MEMBER, READ_REPLICA, NONE };
+
 enum class Instance_column_md { ATTRIBUTES, ADDRESSES };
 
+std::string to_string(const Instance_type instance_type);
+Instance_type to_instance_type(const std::string &instance_type);
+
 struct Instance_metadata {
   Cluster_id cluster_id;
   Instance_id id = 0;
@@ -65,9 +73,13 @@ struct Instance_metadata {
   uint32_t server_id = 0;
   bool hidden_from_router = false;
   std::string cert_subject;
+  Instance_type instance_type = Instance_type::NONE;
+
+  shcore::Dictionary_t tags = nullptr;
 
   // GR clusters only
   std::string group_name;
+  Replica_type replica_type = Replica_type::GROUP_MEMBER;
 
   // Async clusters only
   Instance_id master_id = 0;
@@ -86,6 +98,8 @@ struct Cluster_metadata {
   std::string description;
   bool enabled = true;
 
+  shcore::Dictionary_t tags = nullptr;
+
   std::string full_cluster_name() const { return cluster_name; }
 
   // GR specific
@@ -117,21 +131,24 @@ struct Cluster_set_metadata {
 
 struct Router_metadata {
   std::string name;
-  uint64_t id;
+  uint64_t id{0};
   std::string hostname;
-  mysqlshdk::utils::nullable<std::string> rw_port;
-  mysqlshdk::utils::nullable<std::string> ro_port;
-  mysqlshdk::utils::nullable<std::string> rw_x_port;
-  mysqlshdk::utils::nullable<std::string> ro_x_port;
-  mysqlshdk::utils::nullable<std::string> bootstrap_target_type;
-  mysqlshdk::utils::nullable<std::string> last_checkin;
-  mysqlshdk::utils::nullable<std::string> version;
-  mysqlshdk::utils::nullable<std::string> target_cluster;
+  std::optional<std::string> rw_port;
+  std::optional<std::string> ro_port;
+  std::optional<std::string> rw_x_port;
+  std::optional<std::string> ro_x_port;
+  std::optional<std::string> rw_split_port;
+  std::optional<std::string> bootstrap_target_type;
+  std::optional<std::string> last_checkin;
+  std::optional<std::string> version;
+  std::optional<std::string> target_cluster;
+
+  shcore::Dictionary_t tags = nullptr;
 };
 
-struct Router_options_metadata {
-  mysqlshdk::utils::nullable<std::string> router_label;
-  std::map<std::string, shcore::Value> defined_options;
+struct Routing_options_metadata {
+  std::map<std::string, shcore::Value> global;
+  std::map<std::string, std::map<std::string, shcore::Value>> routers;
 };
 
 class Cluster_impl;
@@ -183,7 +200,8 @@ class MetadataStorage {
    */
   bool check_instance_type(const std::string &uuid,
                            const mysqlshdk::utils::Version &md_version,
-                           Cluster_type *out_type) const;
+                           Cluster_type *out_type,
+                           Replica_type *out_replica_type) const;
 
   bool check_all_members_online() const;
 
@@ -225,9 +243,11 @@ class MetadataStorage {
       Cluster_set_impl *cs, Cluster_id seed_cluster_id,
       shcore::Dictionary_t seed_attributes);
 
-  Instance_id insert_instance(const Instance_metadata &instance);
+  Instance_id insert_instance(const Instance_metadata &instance,
+                              Transaction_undo *undo = nullptr);
   void update_instance(const Instance_metadata &instance);
-  void remove_instance(const std::string &instance_address);
+  void remove_instance(std::string_view instance_address,
+                       Transaction_undo *undo = nullptr);
   void drop_cluster(const std::string &cluster_name,
                     Transaction_undo *undo = nullptr);
 
@@ -238,9 +258,14 @@ class MetadataStorage {
                                std::string_view attribute,
                                shcore::Value *out_value) const;
 
+  void remove_cluster_attribute(const Cluster_id &cluster_id,
+                                std::string_view attribute);
+
   void update_cluster_attribute(const Cluster_id &cluster_id,
                                 std::string_view attribute,
-                                const shcore::Value &value);
+                                const shcore::Value &value,
+                                bool store_null = false);
+
   void update_clusters_attribute(std::string_view attribute,
                                  const shcore::Value &value);
 
@@ -250,7 +275,7 @@ class MetadataStorage {
       const std::set<std::string> &allowed_operations);
 
   bool query_cluster_capability(const Cluster_id &cluster_id,
-                                const std::string &capability,
+                                std::string_view capability,
                                 shcore::Value *out_value) const;
 
   void update_cluster_set_attribute(const Cluster_set_id &clusterset_id,
@@ -265,9 +290,13 @@ class MetadataStorage {
                                 std::string_view attribute,
                                 shcore::Value *out_value) const;
 
+  void remove_instance_attribute(std::string_view uuid,
+                                 std::string_view attribute);
+
   void update_instance_attribute(std::string_view uuid,
                                  std::string_view attribute,
                                  const shcore::Value &value,
+                                 bool store_null = false,
                                  Transaction_undo *undo = nullptr);
 
   void update_instance_addresses(std::string_view uuid,
@@ -299,22 +328,9 @@ class MetadataStorage {
   void set_cluster_tag(const std::string &uuid, const std::string &tagname,
                        const shcore::Value &value);
 
-  /**
-   * Returns the list of tags for a given instance stored on the metadata
-   * @param uuid The uuid of the instance
-   * @return string with the json object representation of the tags for the
-   * given instance. Empty string means there are no tags.
-   */
-  std::string get_instance_tags(const std::string &uuid) const;
-
-  /**
-   * Returns the list of tags for a given cluster/replicaset stored on the
-   * metadata
-   * @param uuid The uuid of the cluster/replicaset
-   * @return string with the json object representation of the tags for the
-   * given cluster/replicaset. Empty string means there are no tags.
-   */
-  std::string get_cluster_tags(const std::string &uuid) const;
+  void set_router_tag(Cluster_type type, const std::string &cluster_id,
+                      const std::string &router, const std::string &tagname,
+                      const shcore::Value &value);
 
   /**
    * Update the information on the metadata about the recovery user being used
@@ -326,21 +342,32 @@ class MetadataStorage {
    * of the instance with the given uuid is dropped from the metadata.
    * @param recovery_account_host string with the host of the recovery user.
    */
-  void update_instance_repl_account(const std::string &instance_uuid,
+  void update_instance_repl_account(std::string_view instance_uuid,
                                     Cluster_type type,
-                                    const std::string &recovery_account_user,
-                                    const std::string &recovery_account_host,
-                                    Transaction_undo *undo = nullptr);
+                                    Replica_type replica_type,
+                                    std::string_view recovery_account_user,
+                                    std::string_view recovery_account_host,
+                                    Transaction_undo *undo = nullptr) const;
+
+  void update_instance_uuid(Cluster_id cluster_id, Instance_id instance_id,
+                            std::string_view instance_uuid);
+
   /**
    * Fetch from the metadata the recovery account being used by the instance
    * with the given uuid.
    * @param instance_uuid the uuid of the instance
    * @param type whether account is for ReplicaSet or Cluster
+   * @para replica_type GROUP_MEMBER or READ_REPLICA
    * @return a pair with the recovery account user name and recovery account
    * hostname
    */
   std::pair<std::string, std::string> get_instance_repl_account(
-      const std::string &instance_uuid, Cluster_type type);
+      const std::string &instance_uuid, Cluster_type type,
+      Replica_type replica_type);
+
+  std::string get_instance_repl_account_user(std::string_view instance_uuid,
+                                             Cluster_type type,
+                                             Replica_type replica_type);
 
   void update_cluster_repl_account(const Cluster_id &cluster_id,
                                    const std::string &repl_account_user,
@@ -350,6 +377,16 @@ class MetadataStorage {
   std::pair<std::string, std::string> get_cluster_repl_account(
       const Cluster_id &cluster_id) const;
 
+  std::string get_cluster_repl_account_user(const Cluster_id &cluster_id) const;
+
+  std::pair<std::string, std::string> get_read_replica_repl_account(
+      const std::string &instance_uuid) const;
+
+  void update_read_replica_repl_account(const std::string &instance_uuid,
+                                        const std::string &repl_account_user,
+                                        const std::string &repl_account_host,
+                                        Transaction_undo *undo = nullptr);
+
   /**
    * Fetch from the metadata list of server uuids
    * with recovery account information.
@@ -365,9 +402,6 @@ class MetadataStorage {
 
   std::vector<std::string> get_recovery_account_users();
 
-  std::string get_recovery_account_user(const Cluster_id &cluster_id,
-                                        const std::string &address);
-
   size_t iterate_recovery_account(
       const std::function<bool(uint32_t, std::string)> &cb);
 
@@ -421,32 +455,69 @@ class MetadataStorage {
                                     std::string *out_primary_id,
                                     uint64_t *out_view_id);
 
-  std::vector<Instance_metadata> get_all_instances(Cluster_id cluster_id = "");
+  std::vector<Instance_metadata> get_all_instances(
+      Cluster_id cluster_id = "", bool include_read_replicas = false);
 
-  Instance_metadata get_instance_by_uuid(const std::string &uuid) const;
+  Instance_metadata get_instance_by_uuid(
+      std::string_view uuid, const Cluster_id &cluster_id = "") const;
 
   Instance_metadata get_instance_by_address(
-      const std::string &instance_address);
+      std::string_view instance_address,
+      const Cluster_id &cluster_id = "") const;
+
+  Instance_metadata get_instance_by_label(std::string_view label) const;
 
   std::vector<Instance_metadata> get_replica_set_instances(
       const Cluster_id &rs_id);
 
   std::vector<Router_metadata> get_routers(const Cluster_id &cluster_id);
   std::vector<Router_metadata> get_clusterset_routers(const Cluster_set_id &cs);
-  std::vector<Router_options_metadata> get_routing_options(
-      const Cluster_set_id &clusterset_id);
+
+  Routing_options_metadata get_routing_options(Cluster_type type,
+                                               const std::string &id);
+
+  shcore::Value get_router_options(Cluster_type type, const std::string &id,
+                                   const std::string &router_name = "");
+
+  mysqlshdk::utils::Version get_router_version(Cluster_type type,
+                                               const std::string &id,
+                                               const std::string &router_name);
+
+  mysqlshdk::utils::Version get_highest_bootstrapped_router_version(
+      Cluster_type type, const std::string &id);
+
+  mysqlshdk::utils::Version get_highest_router_configuration_schema_version(
+      Cluster_type type, const std::string &id);
+
+  shcore::Value get_default_router_options(
+      Cluster_type type, const std::string &id,
+      const mysqlshdk::utils::Version &max_version);
+
+  shcore::Value get_router_configuration_changes_schema(
+      Cluster_type type, const std::string &id,
+      const mysqlshdk::utils::Version &max_version);
+
   std::string get_cluster_name(const std::string &group_replication_group_name);
   std::string get_cluster_group_name(const std::string &cluster_name);
 
-  void set_clusterset_global_routing_option(const Cluster_set_id &id,
-                                            const std::string option,
-                                            const shcore::Value &value);
+  void set_global_routing_option(Cluster_type type, const std::string &id,
+                                 const std::string &option,
+                                 const shcore::Value &value);
 
-  void set_routing_option(const std::string &router,
-                          const std::string &clusterset_id,
+  void set_routing_option(Cluster_type type, const std::string &router,
+                          const std::string &cluster_id,
                           const std::string &option,
                           const shcore::Value &value);
 
+  shcore::Value get_global_routing_option(Cluster_type type,
+                                          const std::string &cluster_id,
+                                          const std::string &option);
+
+  shcore::Value get_routing_option(Cluster_type type,
+                                   const std::string &cluster_id,
+                                   const std::string &router,
+                                   const std::string &option);
+
   /**
    * Get the topology mode of the cluster from the metadata.
    *
@@ -480,10 +551,9 @@ class MetadataStorage {
    * Deletes metadata for the named router instance.
    *
    * @param router_def router identifier, as address[::name]
-   * @param lock_metadata controls if the metadata is locked for the operation
    * @return false if router_def doesn't match any router instances
    */
-  bool remove_router(const std::string &router_def, bool lock_metadata = false);
+  bool remove_router(const std::string &router_def);
 
   /**
    * Sets a target-cluster for all Routers of a Cluster
@@ -503,6 +573,16 @@ class MetadataStorage {
   void migrate_routers_to_clusterset(const Cluster_id &cluster_id,
                                      const Cluster_set_id &cluster_set_id);
 
+  /**
+   * Migrates the Read Only Targets setting from a Cluster to a ClusterSet when
+   * it becomes a ClusterSet
+   *
+   * @param cluster_id The target Cluster ID
+   * @param cluster_set_id The target clusterSet ID to be set
+   */
+  void migrate_read_only_targets_to_clusterset(
+      const Cluster_id &cluster_id, const Cluster_set_id &cluster_set_id);
+
   /**
    * Gets all routers using a Cluster as Target Cluster
    *
@@ -513,6 +593,8 @@ class MetadataStorage {
   std::vector<Router_metadata> get_routers_using_cluster_as_target(
       const Cluster_id &cluster_id);
 
+  shcore::Value get_router_info(const std::string &router_name);
+
   // Async cluster view operations
   Instance_id record_async_member_added(const Instance_metadata &member);
   void record_async_member_rejoined(const Instance_metadata &member);
@@ -572,7 +654,8 @@ class MetadataStorage {
   }
 
   bool check_metadata(mysqlshdk::utils::Version *out_version = nullptr,
-                      Cluster_type *out_type = nullptr) const;
+                      Cluster_type *out_type = nullptr,
+                      Replica_type *out_replica_type = nullptr) const;
 
   bool check_cluster_set(
       const mysqlshdk::mysql::IInstance *target_instance = nullptr,
@@ -582,39 +665,19 @@ class MetadataStorage {
 
   bool supports_cluster_set() const;
 
-  /**
-   * Try to acquire an exclusive lock on the metadata.
-   *
-   * NOTE: Required lock service UDFs which is assumed to be already available
-   *       if supported (automatically installed if needed by the instance
-   *       level lock).
-   *
-   * @throw shcore::Exception if the lock cannot be acquired or any other
-   * error occur when trying to obtain the lock.
-   */
-  void get_lock_exclusive() const;
-
-  /**
-   * Release all locks on the metadata.
-   *
-   * @param no_throw boolean indicating if exceptions are thrown in case a
-   *                 failure occur releasing locks. By default, true meaning
-   *                 that no exception is thrown.
-   *
-   */
-  void release_lock(bool no_throw = true) const;
+  bool supports_read_replicas() const;
 
   class Transaction {
    public:
-    explicit Transaction(const std::shared_ptr<MetadataStorage> &md)
-        : _md(md), m_check_for_auto_commits(false) {
-      md->execute_sql("START TRANSACTION");
+    explicit Transaction(std::shared_ptr<MetadataStorage> md)
+        : m_md{std::move(md)} {
+      m_md->execute_sql("START TRANSACTION");
 #ifndef NDEBUG
-      if (getenv("MYSQLSH_TEST_ALL")) m_check_for_auto_commits = true;
+      m_check_for_auto_commits = getenv("MYSQLSH_TEST_ALL");
 #endif
     }
 
-    ~Transaction() {
+    ~Transaction() noexcept {
       try {
         rollback();
       } catch (const std::exception &e) {
@@ -623,39 +686,31 @@ class MetadataStorage {
     }
 
     void rollback() {
-      if (_md) {
+      if (!m_md) return;
 #ifndef NDEBUG
-        if (m_check_for_auto_commits) {
-          mysqlshdk::mysql::assert_transaction_is_open(
-              _md->get_md_server()->get_session());
-        }
-#endif
-        auto tmp = _md;
-        _md.reset();
-        tmp->execute_sql("ROLLBACK");
+      if (m_check_for_auto_commits) {
+        mysqlshdk::mysql::assert_transaction_is_open(
+            m_md->get_md_server()->get_session());
       }
+#endif
+      std::exchange(m_md, nullptr)->execute_sql("ROLLBACK");
     }
 
     void commit() {
-      if (_md) {
-#ifndef NDEBUG
-        if (m_check_for_auto_commits) {
-          mysqlshdk::mysql::assert_transaction_is_open(
-              _md->get_md_server()->get_session());
-        }
-#endif
+      if (!m_md) return;
 
-        auto tmp = _md;
-        _md.reset();
-        tmp->execute_sql("COMMIT");
+#ifndef NDEBUG
+      if (m_check_for_auto_commits) {
+        mysqlshdk::mysql::assert_transaction_is_open(
+            m_md->get_md_server()->get_session());
       }
+#endif
+      std::exchange(m_md, nullptr)->execute_sql("COMMIT");
     }
 
    private:
-    std::shared_ptr<MetadataStorage> _md;
-#ifdef __clang__
-    [[maybe_unused]] bool m_check_for_auto_commits = false;
-#else
+    std::shared_ptr<MetadataStorage> m_md;
+#ifndef NDEBUG
     bool m_check_for_auto_commits = false;
 #endif
   };
@@ -665,14 +720,9 @@ class MetadataStorage {
                                const char *operation, uint32_t *out_aclvid,
                                uint32_t *last_aclvid);
 
-  void set_table_tag(const std::string &tablename,
-                     const std::string &uuid_column_name,
-                     const std::string &uuid, const std::string &tagname,
-                     const shcore::Value &value);
-
-  std::string get_table_tags(const std::string &tablename,
-                             const std::string &uuid_column_name,
-                             const std::string &uuid) const;
+  void set_table_tag(std::string_view tablename,
+                     std::string_view uuid_column_name, std::string_view uuid,
+                     std::string_view tagname, const shcore::Value &value);
 
   bool cluster_sets_supported() const;
 
@@ -697,7 +747,7 @@ class MetadataStorage {
 
   template <typename... Args>
   inline std::shared_ptr<mysqlshdk::db::IResult> execute_sqlf(
-      const std::string &sql, const Args &... args) const {
+      const std::string &sql, const Args &...args) const {
     return execute_sql(shcore::sqlformat(sql, args...));
   }
 
