@@ -25,17 +25,14 @@
 
 #include "modules/adminapi/common/preconditions.h"
 
-#include <mysqld_error.h>
 #include <map>
 
+#include "modules/adminapi/cluster/cluster_impl.h"
 #include "modules/adminapi/cluster_set/cluster_set_impl.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/instance_pool.h"
-#include "modules/adminapi/common/sql.h"
-#include "mysqlshdk/include/shellcore/scoped_contexts.h"
-#include "mysqlshdk/libs/db/utils_error.h"
-#include "mysqlshdk/libs/mysql/group_replication.h"
+#include "modules/adminapi/common/metadata_storage.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -210,16 +207,18 @@ const mysqlshdk::utils::Version
 
 // The AdminAPI minimum supported MySQL Server version
 const mysqlshdk::utils::Version
-    Precondition_checker::k_min_adminapi_server_version(5, 7, 0);
+    Precondition_checker::k_min_adminapi_server_version(8, 0, 0);
 
-// The AdminAPI deprecated version
+// The AdminAPI deprecated version (currently disabled)
 const mysqlshdk::utils::Version
-    Precondition_checker::k_deprecated_adminapi_server_version(5, 7, 9999);
+    Precondition_checker::k_deprecated_adminapi_server_version{};
 
-const mysqlshdk::utils::Version Precondition_checker::k_min_gr_version(5, 7);
+const mysqlshdk::utils::Version Precondition_checker::k_min_gr_version(8, 0);
 const mysqlshdk::utils::Version Precondition_checker::k_min_ar_version(8, 0);
 const mysqlshdk::utils::Version Precondition_checker::k_min_cs_version(8, 0,
                                                                        27);
+const mysqlshdk::utils::Version Precondition_checker::k_min_rr_version(8, 0,
+                                                                       23);
 
 const std::map<std::string, Function_availability>
     Precondition_checker::s_preconditions = {
@@ -267,17 +266,6 @@ const std::map<std::string, Function_availability>
            {metadata::kCompatibleLower, MDS_actions::NOTE}},
           k_primary_not_required,
           kClusterGlobalStateAny}},
-        {"Dba.configureLocalInstance",
-         {k_min_gr_version,
-          TargetType::Standalone | TargetType::StandaloneWithMetadata |
-              TargetType::StandaloneInMetadata | TargetType::InnoDBCluster |
-              TargetType::InnoDBClusterSet |
-              TargetType::InnoDBClusterSetOffline | TargetType::Unknown |
-              TargetType::GroupReplication,
-          ReplicationQuorum::State::any(),
-          {},
-          k_primary_not_required,
-          kClusterGlobalStateAny}},
         {"Dba.checkInstanceConfiguration",
          {k_min_gr_version,
           TargetType::Standalone | TargetType::StandaloneWithMetadata |
@@ -407,13 +395,6 @@ const std::map<std::string, Function_availability>
           k_primary_required,
           kClusterGlobalStateAny,
           true}},
-        {"Cluster.checkInstanceState",
-         {k_min_gr_version,
-          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
-          ReplicationQuorum::State(ReplicationQuorum::States::Normal),
-          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}},
-          k_primary_required,
-          kClusterGlobalStateAny}},
         {"Cluster.rescan",
          {k_min_gr_version,
           TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
@@ -448,8 +429,8 @@ const std::map<std::string, Function_availability>
           {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
           k_primary_not_required,  // In case of a Cluster, because we have to
                                    // have all members online, the primary is
-                                   // automaticly also available. But in case of
-                                   // a ClusterSet, this refers to the set's
+                                   // automatically also available. But in case
+                                   // of a ClusterSet, this refers to the set's
                                    // primary, which isn't required
           kClusterGlobalStateAny}},
         {"Cluster.setOption",
@@ -474,6 +455,29 @@ const std::map<std::string, Function_availability>
           k_primary_not_required,
           kClusterGlobalStateAny,
           true}},
+        {"Cluster.setRoutingOption",
+         {k_min_gr_version,
+          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
+          ReplicationQuorum::State::any(),
+          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
+          k_primary_required,
+          kClusterGlobalStateAnyOk}},
+        {"Cluster.routingOptions",
+         {k_min_gr_version,
+          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
+          ReplicationQuorum::State::any(),
+          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}},
+          k_primary_required,
+          kClusterGlobalStateAny,
+          k_allowed_on_fence}},
+        {"Cluster.routerOptions",
+         {k_min_gr_version,
+          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
+          ReplicationQuorum::State::any(),
+          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}},
+          k_primary_required,
+          kClusterGlobalStateAny,
+          k_allowed_on_fence}},
         {"Cluster.removeRouterMetadata",
          {k_min_gr_version,
           TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
@@ -538,8 +542,14 @@ const std::map<std::string, Function_availability>
           {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR},
            {metadata::kIncompatible, MDS_actions::WARN},
            {metadata::kCompatibleLower, MDS_actions::NOTE}},
-          k_primary_not_required}},
-
+          k_primary_required}},
+        {"Cluster.addReplicaInstance",
+         {k_min_rr_version,
+          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
+          ReplicationQuorum::State(ReplicationQuorum::States::Normal),
+          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
+          k_primary_required,
+          Cluster_global_status_mask(Cluster_global_status::OK)}},
         // ClusterSet Functions
         {"ClusterSet.createReplicaCluster",
          {k_min_cs_version,
@@ -589,7 +599,8 @@ const std::map<std::string, Function_availability>
         {"ClusterSet.setRoutingOption",
          {k_min_cs_version,
           TargetType::InnoDBClusterSet,
-          ReplicationQuorum::State::any(),
+          ReplicationQuorum::State::any(),  // XXX review these? shouldn't be
+                                            // Online only?
           {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
           k_primary_required,
           kClusterGlobalStateAnyOk}},
@@ -598,7 +609,15 @@ const std::map<std::string, Function_availability>
           TargetType::InnoDBClusterSet,
           ReplicationQuorum::State::any(),
           {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}},
-          k_primary_required,
+          k_primary_not_required,
+          kClusterGlobalStateAny,
+          k_allowed_on_fence}},
+        {"ClusterSet.routerOptions",
+         {k_min_cs_version,
+          TargetType::InnoDBClusterSet,
+          ReplicationQuorum::State::any(),
+          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}},
+          k_primary_not_required,
           kClusterGlobalStateAny,
           k_allowed_on_fence}},
         {"ClusterSet.listRouters",
@@ -692,8 +711,11 @@ const std::map<std::string, Function_availability>
           TargetType::AsyncReplicaSet,
           na_quorum,
           {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}}}},
-        {"ReplicaSet.checkInstanceState",
-         {k_min_ar_version, TargetType::AsyncReplicaSet, na_quorum, {}}},
+        {"ReplicaSet.rescan",
+         {k_min_ar_version,
+          TargetType::AsyncReplicaSet,
+          na_quorum,
+          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}}}},
         {"ReplicaSet.setPrimaryInstance",
          {k_min_ar_version,
           TargetType::AsyncReplicaSet,
@@ -726,6 +748,21 @@ const std::map<std::string, Function_availability>
           TargetType::AsyncReplicaSet,
           na_quorum,
           {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}}}},
+        {"ReplicaSet.setRoutingOption",
+         {k_min_ar_version,
+          TargetType::AsyncReplicaSet,
+          na_quorum,
+          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}}}},
+        {"ReplicaSet.routingOptions",
+         {k_min_ar_version,
+          TargetType::AsyncReplicaSet,
+          na_quorum,
+          {{metadata::kUpgradeStates, MDS_actions::RAISE_ERROR}}}},
+        {"ReplicaSet.routerOptions",
+         {k_min_ar_version,
+          TargetType::AsyncReplicaSet,
+          na_quorum,
+          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}}}},
         {"ReplicaSet.setOption",
          {k_min_ar_version,
           TargetType::AsyncReplicaSet,
@@ -786,8 +823,9 @@ void Precondition_checker::check_session() const {
   }
 
   // Print a warning for deprecated version
-  if (server_version <=
-      Precondition_checker::k_deprecated_adminapi_server_version) {
+  if (Precondition_checker::k_deprecated_adminapi_server_version &&
+      (server_version <=
+       Precondition_checker::k_deprecated_adminapi_server_version)) {
     mysqlsh::current_console()->print_warning(
         "Support for AdminAPI operations in MySQL version " +
         Precondition_checker::k_deprecated_adminapi_server_version.get_short() +
@@ -798,34 +836,27 @@ void Precondition_checker::check_session() const {
 
 namespace ManagedInstance {
 std::string describe(State state) {
-  std::string ret_val;
   switch (state) {
     case OnlineRW:
-      ret_val = "Read/Write";
-      break;
+      return "Read/Write";
     case OnlineRO:
-      ret_val = "Read Only";
-      break;
+      return "Read Only";
     case Recovering:
-      ret_val = "Recovering";
-      break;
+      return "Recovering";
     case Unreachable:
-      ret_val = "Unreachable";
-      break;
+      return "Unreachable";
     case Offline:
-      ret_val = "Offline";
-      break;
+      return "Offline";
     case Error:
-      ret_val = "Error";
-      break;
+      return "Error";
     case Missing:
-      ret_val = "(Missing)";
-      break;
+      return "(Missing)";
     case Any:
       assert(0);  // FIXME(anyone) avoid using enum as a bitmask
       break;
   }
-  return ret_val;
+
+  return {};
 }
 }  // namespace ManagedInstance
 
