@@ -37,23 +37,20 @@
 #include "mysqlshdk/include/scripting/types_cpp.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 
-namespace mysqlsh {
-namespace dba {
-namespace replicaset {
+namespace mysqlsh::dba::replicaset {
 
-struct Wait_recovery_option {
-  static const shcore::Option_pack_def<Wait_recovery_option> &options();
+struct Recovery_progress_option {
+  static const shcore::Option_pack_def<Recovery_progress_option> &options();
 
-  void set_wait_recovery(const std::string &option, int value);
-  Recovery_progress_style get_wait_recovery();
+  void set_recovery_progress(int value);
+  Recovery_progress_style get_recovery_progress();
 
  private:
-  std::optional<Recovery_progress_style> m_wait_recovery, m_recovery_progress;
+  std::optional<Recovery_progress_style> m_recovery_progress;
 };
 
-struct Rejoin_instance_options : public Wait_recovery_option,
-                                 public Timeout_option,
-                                 public Interactive_option {
+struct Rejoin_instance_options : public Recovery_progress_option,
+                                 public Timeout_option {
   static const shcore::Option_pack_def<Rejoin_instance_options> &options();
 
   Join_replicaset_clone_options clone_options;
@@ -64,6 +61,13 @@ struct Add_instance_options : public Rejoin_instance_options {
   static const shcore::Option_pack_def<Add_instance_options> &options();
 
   void set_cert_subject(const std::string &value);
+  void set_repl_connect_retry(int value);
+  void set_repl_retry_count(int value);
+  void set_repl_heartbeat_period(double value);
+  void set_repl_compression_algos(const std::string &value);
+  void set_repl_zstd_compression_level(int value);
+  void set_repl_bind(const std::string &value);
+  void set_repl_network_namespace(const std::string &value);
 
   Async_replication_options ar_options;
   std::string instance_label;
@@ -105,7 +109,25 @@ struct Force_primary_instance_options : public Set_primary_instance_options {
   bool invalidate_instances = false;
 };
 
-}  // namespace replicaset
-}  // namespace dba
-}  // namespace mysqlsh
+struct Dissolve_options {
+  static const shcore::Option_pack_def<Dissolve_options> &options();
+
+  bool force{false};
+
+  std::chrono::seconds timeout() const;
+  void set_timeout(int value);
+
+ private:
+  std::optional<std::chrono::seconds> m_timeout;
+};
+
+struct Rescan_options {
+  static const shcore::Option_pack_def<Rescan_options> &options();
+
+  bool add_unmanaged = false;
+  bool remove_obsolete = false;
+};
+
+}  // namespace mysqlsh::dba::replicaset
+
 #endif  // MODULES_ADMINAPI_REPLICA_SET_API_OPTIONS_H_
