@@ -29,6 +29,7 @@
 #include <list>
 #include <memory>
 #include <string>
+#include <tuple>
 #include <utility>
 #include <vector>
 
@@ -41,12 +42,15 @@
 #include "modules/adminapi/common/global_topology_manager.h"
 #include "modules/adminapi/common/gtid_validations.h"
 #include "modules/adminapi/dba/api_options.h"
+#include "modules/adminapi/replica_set/api_options.h"
 #include "mysqlshdk/libs/db/connection_options.h"
 
 namespace mysqlsh {
 namespace dba {
 
-class Replica_set_impl : public Base_cluster_impl {
+inline constexpr const char *k_async_cluster_user_name = "mysql_innodb_rs_";
+
+class Replica_set_impl final : public Base_cluster_impl {
  public:
   Replica_set_impl(const std::string &cluster_name,
                    const std::shared_ptr<Instance> &target,
@@ -73,10 +77,13 @@ class Replica_set_impl : public Base_cluster_impl {
       const std::shared_ptr<Instance> &target_server,
       const Create_replicaset_options &options);
 
-  shcore::Value describe() {
-    check_preconditions("describe");
-    throw std::logic_error("not implemented");
-  }
+  static std::vector<std::tuple<mysqlshdk::mysql::Slave_host, std::string>>
+  get_valid_slaves(
+      const mysqlshdk::mysql::IInstance &instance,
+      std::vector<std::tuple<mysqlshdk::mysql::Slave_host, std::string>>
+          *ghost_slaves);
+
+  shcore::Value describe();
 
   shcore::Value status(int extended);
 
@@ -101,22 +108,14 @@ class Replica_set_impl : public Base_cluster_impl {
   void force_primary_instance(const std::string &instance_def, uint32_t timeout,
                               bool invalidate_error_instances, bool dry_run);
 
+  void dissolve(const replicaset::Dissolve_options &options);
+  void rescan(const replicaset::Rescan_options &options);
+
   shcore::Value options();
 
-  void dissolve(const shcore::Dictionary_t & /*opts*/ = {}) {
-    check_preconditions("dissolve");
-    throw std::logic_error("not supported");
-  }
-
-  shcore::Value check_instance_state(
-      const Connection_options & /*instance_def*/) {
-    check_preconditions("checkInstanceState");
-    throw std::logic_error("not implemented");
-  }
-
   shcore::Value list_routers(bool only_upgrade_required) override;
 
-  void remove_router_metadata(const std::string &router);
+  void remove_router_metadata(const std::string &router) override;
 
   void setup_admin_account(const std::string &username, const std::string &host,
                            const Setup_account_options &options) override;
@@ -127,7 +126,7 @@ class Replica_set_impl : public Base_cluster_impl {
 
   std::list<std::shared_ptr<Instance>> connect_all_members(
       uint32_t read_timeout, bool skip_primary,
-      std::list<Instance_metadata> *out_unreachable);
+      std::list<Instance_metadata> *out_unreachable, bool silent = false);
 
   std::tuple<mysqlsh::dba::Instance *, mysqlshdk::mysql::Lock_scoped>
   acquire_primary_locked(mysqlshdk::mysql::Lock_mode mode,
@@ -146,11 +145,35 @@ class Replica_set_impl : public Base_cluster_impl {
   void drop_replication_user(const std::string &server_uuid,
                              mysqlshdk::mysql::IInstance *slave = nullptr);
 
+  void drop_all_replication_users();
+
   std::pair<mysqlshdk::mysql::Auth_options, std::string>
   create_replication_user(mysqlshdk::mysql::IInstance *slave,
                           std::string_view auth_cert_subject, bool dry_run,
                           mysqlshdk::mysql::IInstance *master = nullptr);
 
+  std::vector<Instance_metadata> get_instances_from_metadata() const override;
+
+  void ensure_compatible_clone_donor(
+      const mysqlshdk::mysql::IInstance &donor,
+      const mysqlshdk::mysql::IInstance &recipient) const;
+
+  std::shared_ptr<Global_topology_manager> get_topology_manager(
+      topology::Server_global_topology **out_topology = nullptr,
+      bool deep = false) const;
+
+  void read_replication_options(std::string_view instance_uuid,
+                                Async_replication_options *ar_options,
+                                bool *has_null_options);
+
+  // Lock methods
+
+  [[nodiscard]] mysqlshdk::mysql::Lock_scoped get_lock_shared(
+      std::chrono::seconds timeout = {}) override;
+
+  [[nodiscard]] mysqlshdk::mysql::Lock_scoped get_lock_exclusive(
+      std::chrono::seconds timeout = {}) override;
+
  private:
   void _set_option(const std::string &option,
                    const shcore::Value &value) override;
@@ -171,10 +194,10 @@ class Replica_set_impl : public Base_cluster_impl {
                              Clone_options *clone_options,
                              const std::string &cert_subject, bool interactive);
 
-  void validate_rejoin_instance(Global_topology_manager *topology_mng,
-                                Instance *target, Clone_options *clone_options,
-                                Instance_metadata *out_instance_md,
-                                bool interactive);
+  topology::Node_status validate_rejoin_instance(
+      Global_topology_manager *topology_mng, Instance *target,
+      Clone_options *clone_options, Instance_metadata *out_instance_md,
+      bool interactive);
 
   void validate_remove_instance(Global_topology_manager *topology,
                                 mysqlshdk::mysql::IInstance *master,
@@ -191,13 +214,7 @@ class Replica_set_impl : public Base_cluster_impl {
   void do_set_primary_instance(
       Instance *master, Instance *new_master,
       const std::list<std::shared_ptr<Instance>> &instances,
-      const Async_replication_options &ar_options, bool dry_run);
-
-  std::shared_ptr<Global_topology_manager> setup_topology_manager(
-      topology::Server_global_topology **out_topology = nullptr,
-      bool deep = false);
-
-  std::vector<Instance_metadata> get_instances_from_metadata() const;
+      const Async_replication_options &master_ar_options, bool dry_run);
 
   const topology::Server *check_target_member(
       topology::Server_global_topology *topology,
@@ -208,7 +225,8 @@ class Replica_set_impl : public Base_cluster_impl {
       std::list<std::shared_ptr<Instance>> *out_online_instances,
       bool invalidate_error_instances,
       std::vector<Instance_metadata> *out_instances_md,
-      std::list<Instance_id> *out_invalidate_ids) const;
+      std::list<Instance_id> *out_invalidate_ids,
+      std::list<std::string> *out_ids_applier_off) const;
 
   void primary_instance_did_change(
       const std::shared_ptr<Instance> &new_primary = {});
@@ -216,25 +234,16 @@ class Replica_set_impl : public Base_cluster_impl {
   void invalidate_handle();
 
   void ensure_metadata_has_server_uuid(const mysqlsh::dba::Instance &instance);
-  void ensure_compatible_donor(const std::string &instance_def,
-                               mysqlshdk::mysql::IInstance *recipient);
 
   std::string pick_clone_donor(mysqlshdk::mysql::IInstance *recipient);
 
   void revert_topology_changes(mysqlshdk::mysql::IInstance *target_server,
                                bool remove_user, bool dry_run);
 
-  void handle_clone(const std::shared_ptr<mysqlsh::dba::Instance> &recipient,
-                    const Clone_options &clone_options,
-                    const Async_replication_options &ar_options,
-                    const std::string &repl_account_host,
-                    const std::string &repl_account_cert_subject,
-                    const Recovery_progress_style &progress_style,
-                    int sync_timeout, bool dry_run);
-
   Member_recovery_method validate_instance_recovery(
-      Member_op_action op_action, mysqlshdk::mysql::IInstance *donor_instance,
-      mysqlshdk::mysql::IInstance *target_instance,
+      Member_op_action op_action,
+      const mysqlshdk::mysql::IInstance &donor_instance,
+      const mysqlshdk::mysql::IInstance &target_instance,
       Member_recovery_method opt_recovery_method, bool gtid_set_is_complete,
       bool interactive);
 
@@ -246,7 +255,13 @@ class Replica_set_impl : public Base_cluster_impl {
       const std::string &function_name,
       bool throw_if_primary_unavailable = true);
 
-  void read_replication_options(Async_replication_options *ar_options);
+  void read_replication_options(const mysqlshdk::mysql::IInstance *instance,
+                                Async_replication_options *ar_options,
+                                bool *has_null_options = nullptr);
+  void cleanup_replication_options(const mysqlshdk::mysql::IInstance &instance);
+
+  [[nodiscard]] mysqlshdk::mysql::Lock_scoped get_lock(
+      mysqlshdk::mysql::Lock_mode mode, std::chrono::seconds timeout = {});
 
   Global_topology_type m_topology_type;
 };
