@@ -24,12 +24,13 @@
  */
 
 #include "crud_definition.h"
+
 #include <mysqld_error.h>
+
 #include <memory>
 #include <string>
 #include <vector>
-#include "db/mysqlx/mysqlx_parser.h"
-#include "db/mysqlx/util/setter_any.h"
+
 #include "db/session.h"
 #include "modules/devapi/base_database_object.h"
 #include "modules/devapi/crud_definition.h"
@@ -37,10 +38,10 @@
 #include "modules/devapi/mod_mysqlx_session.h"
 #include "modules/devapi/protobuf_bridge.h"
 #include "modules/mysqlxtest_utils.h"
-#include "scripting/shexcept.h"
+#include "mysqlshdk/libs/db/utils/utils.h"
+#include "mysqlshdk/libs/utils/atomic_flag.h"
 #include "shellcore/interrupt_handler.h"
 #include "shellcore/utils_help.h"
-#include "utils/utils_general.h"
 #include "utils/utils_string.h"
 
 using std::placeholders::_1;
@@ -53,7 +54,7 @@ Crud_definition::Crud_definition(std::shared_ptr<DatabaseObject> owner)
   try {
     add_method("execute", std::bind(&Crud_definition::execute, this, _1),
                "data");
-  } catch (const shcore::Exception &e) {
+  } catch (const shcore::Exception &) {
     // Invalid typecast exception is the only option
     // The exception is recreated with a more explicit message
     throw shcore::Exception::argument_error(
@@ -65,19 +66,19 @@ Crud_definition::~Crud_definition() { reset_prepared_statement(); }
 void Crud_definition::parse_string_list(const shcore::Argument_list &args,
                                         std::vector<std::string> &data) {
   // When there is 1 argument, it must be either an array of strings or a string
-  if (args.size() == 1 && args[0].type != shcore::Array &&
-      args[0].type != shcore::String)
+  if (args.size() == 1 && args[0].get_type() != shcore::Array &&
+      args[0].get_type() != shcore::String)
     throw shcore::Exception::type_error(
         "Argument #1 is expected to be a string or an array of strings");
 
-  if (args.size() == 1 && args[0].type == shcore::Array) {
+  if (args.size() == 1 && args[0].get_type() == shcore::Array) {
     shcore::Value::Array_type_ref shell_fields = args.array_at(0);
     shcore::Value::Array_type::const_iterator index, end = shell_fields->end();
 
     int count = 0;
     for (index = shell_fields->begin(); index != end; index++) {
       count++;
-      if (index->type != shcore::String)
+      if (index->get_type() != shcore::String)
         throw shcore::Exception::type_error(shcore::str_format(
             "Element #%d is expected to be a string", count));
       else
@@ -90,25 +91,17 @@ void Crud_definition::parse_string_list(const shcore::Argument_list &args,
 }
 
 std::shared_ptr<mysqlshdk::db::mysqlx::Result> Crud_definition::safe_exec(
-    std::function<std::shared_ptr<mysqlshdk::db::IResult>()> func) {
-  bool interrupted = false;
+    const std::function<std::shared_ptr<mysqlshdk::db::IResult>()> &func) {
+  shcore::atomic_flag interrupted;
 
-  std::weak_ptr<ShellBaseSession> weak_session(_owner->session());
-
-  shcore::Interrupt_handler intrl([weak_session, &interrupted]() {
-    try {
-      if (auto session = weak_session.lock()) {
-        interrupted = true;
-        session->kill_query();
-
-        // don't propagate
+  shcore::Interrupt_handler intrl(
+      [&interrupted] {
+        interrupted.test_and_set();
         return false;
-      }
-    } catch (const std::exception &e) {
-      log_warning("Exception trying to kill query: %s", e.what());
-    }
-    return true;
-  });
+      },
+      [weak_session = std::weak_ptr{_owner->session()->get_core_session()}]() {
+        kill_query(weak_session);
+      });
 
   std::shared_ptr<mysqlshdk::db::IResult> result;
 
@@ -146,7 +139,7 @@ std::shared_ptr<mysqlshdk::db::mysqlx::Result> Crud_definition::safe_exec(
     result = func();
   }
 
-  if (result && interrupted) {
+  if (result && interrupted.test()) {
     // If the query was interrupted but it didn't throw an exception
     // from "Error 1317 Query execution was interrupted", it means the
     // interruption happened at a time the query was not active. But we
@@ -157,14 +150,19 @@ std::shared_ptr<mysqlshdk::db::mysqlx::Result> Crud_definition::safe_exec(
 
     log_warning("Flushing resultset data from interrupted query...");
     try {
-      while (result->next_resultset())
-        ;
+      while (result->next_resultset()) {
+      }
       result.reset();
     } catch (const mysqlshdk::db::Error &) {
       throw;
     }
     throw shcore::Exception::runtime_error(
-        "Query interrupted. Results where flushed");
+        "Query interrupted. Results were flushed");
+  }
+
+  if (interrupted.test()) {
+    // query was interrupted but it didn't throw an exception
+    throw shcore::Exception::runtime_error("Query interrupted");
   }
 
   m_execution_count++;
@@ -244,7 +242,7 @@ void Crud_definition::insert_bound_values(
 
 void Crud_definition::encode_expression_object(Mysqlx::Expr::Expr *expr,
                                                const shcore::Value &value) {
-  assert(value.type == shcore::Object);
+  assert(value.get_type() == shcore::Object);
 
   shcore::Object_bridge_ref object = value.as_object();
   std::string object_class = object->class_name();
@@ -274,7 +272,7 @@ void Crud_definition::encode_expression_object(Mysqlx::Expr::Expr *expr,
 
 void Crud_definition::encode_expression_value(Mysqlx::Expr::Expr *expr,
                                               const shcore::Value &value) {
-  switch (value.type) {
+  switch (value.get_type()) {
     case shcore::Undefined:
       throw shcore::Exception::argument_error("Invalid value");
 
@@ -320,7 +318,6 @@ void Crud_definition::encode_expression_value(Mysqlx::Expr::Expr *expr,
       expr->mutable_literal()->set_type(Mysqlx::Datatypes::Scalar::V_NULL);
       break;
 
-    case shcore::MapRef:
     case shcore::Function:
       std::stringstream str;
       str << "Invalid value '" << value.descr() << "' in document";
@@ -358,7 +355,7 @@ shcore::Value Crud_definition::limit(
   args.ensure_count(1, full_name.c_str());
 
   try {
-    if (m_limit.is_null()) reset_prepared_statement();
+    if (!m_limit.has_value()) reset_prepared_statement();
 
     m_limit = args.uint_at(0);
 
