@@ -194,8 +194,9 @@ void Replayer_mysql::do_connect(
   _impl->connect(data);
 }
 
-std::shared_ptr<IResult> Replayer_mysql::querys(const char *sql_, size_t length,
-                                                bool) {
+std::shared_ptr<IResult> Replayer_mysql::querys(
+    const char *sql_, size_t length, bool,
+    [[maybe_unused]] const std::vector<Query_attribute> &query_attributes) {
   std::string sql = _impl->do_query(std::string(sql_, length));
 
   auto log_sql_handler = shcore::current_log_sql();
@@ -292,8 +293,9 @@ void Replayer_mysqlx::do_connect(
   _impl->connect(data);
 }
 
-std::shared_ptr<IResult> Replayer_mysqlx::querys(const char *sql_,
-                                                 size_t length, bool) {
+std::shared_ptr<IResult> Replayer_mysqlx::querys(
+    const char *sql_, size_t length, bool,
+    [[maybe_unused]] const std::vector<Query_attribute> &query_attributes) {
   std::string sql = _impl->do_query(std::string(sql_, length));
 
   auto log_sql_handler = shcore::current_log_sql();
