@@ -26,6 +26,7 @@
  */
 
 #include "mysqlshdk/libs/mysql/mycnf.h"
+
 #include <cstdio>
 #include <fstream>
 
@@ -38,18 +39,20 @@ namespace mycnf {
 
 void update_options(const std::string &path, const std::string &section,
                     const std::vector<Option> &mycnf_options) {
-  std::vector<Option> options(mycnf_options);
   std::ifstream ifs;
-  std::ofstream ofs;
   ifs.open(path);
   if (ifs.fail()) {
     throw std::runtime_error(path + ": " + strerror(errno));
   }
+
+  std::ofstream ofs;
   ofs.open(path + ".tmp");
   if (ofs.fail()) {
     throw std::runtime_error(path + ".tmp: " + strerror(errno));
   }
 
+  std::vector<Option> options(mycnf_options);
+
   try {
     bool found_section = false;
     bool inside_section = false;
@@ -63,18 +66,17 @@ void update_options(const std::string &path, const std::string &section,
           inside_section = true;
         }
       } else if (inside_section) {
-        std::string key;
-        utils::nullable<std::string> value;
-        std::tie(key, value) = shcore::str_partition(line, "=");
-        for (auto opt = options.begin(); opt != options.end(); ++opt) {
-          if (opt->first == key) {
-            if (!opt->second) {
+        auto [key, value] = shcore::str_partition(line, "=");
+
+        for (auto &opt : options) {
+          if (opt.first == key) {
+            if (!opt.second.has_value()) {
               // option set to NULL means erase the option
               skip = true;
             } else {
-              line = key + "=" + *opt->second;
+              line = key + "=" + *opt.second;
             }
-            opt->first.clear();
+            opt.first.clear();
             break;
           }
         }
