@@ -24,11 +24,12 @@
  */
 
 #include "mysqlshdk/libs/utils/strformat.h"
-#include <time.h>
+
 #include <cmath>
-#include <cstdio>
+#include <ctime>
+#include <stdexcept>
 #include <tuple>
-#include <utility>
+
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlshdk {
