@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -76,15 +78,10 @@ std::wstring python_home() {
     // If not will associate what should be the right path in a standard
     // distribution
     std::string python_path = shcore::get_mysqlx_home_path();
+    assert(!python_path.empty());
 
-    if (!python_path.empty()) {
-      python_path =
-          shcore::path::join_path(python_path, "lib", "Python" MAJOR_MINOR);
-    } else {
-      // Not a standard distribution
-      python_path = shcore::get_binary_folder();
-      python_path = shcore::path::join_path(python_path, "Python" MAJOR_MINOR);
-    }
+    python_path =
+        shcore::path::join_path(python_path, "lib", "Python" MAJOR_MINOR);
 
     log_info("Setting Python home to '%s'", python_path.c_str());
     home = python_path;
@@ -115,8 +112,14 @@ std::wstring python_home() {
   return utf8_to_wide(home);
 }
 
-std::wstring program_name() {
-  return utf8_to_wide(g_mysqlsh_path, strlen(g_mysqlsh_path));
+std::wstring python_path(const std::wstring &home) {
+#ifdef _WIN32
+  return utf8_to_wide(shcore::path::join_path(
+      wide_to_utf8(home), shcore::path::basename(PYTHON_EXECUTABLE)));
+#else
+  return utf8_to_wide(shcore::path::join_path(
+      wide_to_utf8(home), "bin", shcore::path::basename(PYTHON_EXECUTABLE)));
+#endif
 }
 
 void pre_initialize_python() {
@@ -173,16 +176,23 @@ void initialize_python() {
   config.install_signal_handlers = 1;
 
   if (const auto home = python_home(); !home.empty()) {
+#ifdef _WIN32
+    // binary folder holds all bundled dlls, including the ones needed by Python
+    SetDllDirectoryW(utf8_to_wide(shcore::get_binary_folder()).c_str());
+#endif
     check_status(PyConfig_SetString(&config, &config.home, home.c_str()),
                  "set Python home");
+
+    check_status(PyConfig_SetString(&config, &config.program_name,
+                                    python_path(home).c_str()),
+                 "set program name");
+  } else {
+    check_status(PyConfig_SetString(&config, &config.program_name,
+                                    utf8_to_wide(PYTHON_EXECUTABLE).c_str()),
+                 "set program name");
   }
-
-  check_status(
-      PyConfig_SetString(&config, &config.program_name, program_name().c_str()),
-      "set program name");
-
-  // we want config.argv to be set to an array holding an empty string, this is
-  // done by default by Python
+  // we want config.argv to be set to an array holding an empty string, this
+  // is done by default by Python
 
   check_status(Py_InitializeFromConfig(&config), "initialize");
 }
@@ -247,14 +257,14 @@ void py_unregister_module(const std::string &name) {
 py::Release py_run_string_interactive(const std::string &str, PyObject *globals,
                                       PyObject *locals,
                                       PyCompilerFlags *flags) {
-  // Previously, we were using PyRun_StringFlags() with the Py_single_input flag
-  // to run the code string and capture its output using a custom
+  // Previously, we were using PyRun_StringFlags() with the Py_single_input
+  // flag to run the code string and capture its output using a custom
   // sys.displayhook, however Python's grammar allows only for a single
-  // statement (simple_stmt or compound_stmt) to be used in such case. Since we
-  // want to be able to run multiple statements at once, Py_file_input flag is
-  // the alternative which allows the code string to be a sequence of
-  // statements, but unfortunately it does not allow to obtain the result of the
-  // execution.
+  // statement (simple_stmt or compound_stmt) to be used in such case. Since
+  // we want to be able to run multiple statements at once, Py_file_input flag
+  // is the alternative which allows the code string to be a sequence of
+  // statements, but unfortunately it does not allow to obtain the result of
+  // the execution.
   //
   // Below, the code string is parsed as a series of statements using the
   // Py_file_input flag, producing the AST representation. We use this
@@ -816,20 +826,28 @@ Value Python_context::execute_interactive(const std::string &code,
   orig_hook.reset();
 
   if (!py_result) {
-    PyObject *exc, *value, *tb;
+#if PY_VERSION_HEX >= 0x030c0000
+    py::Release exc_value{PyErr_GetRaisedException()};
+#else
+    PyObject *type, *value, *tb;
+
+    PyErr_Fetch(&type, &value, &tb);
+    PyErr_NormalizeException(&type, &value, &tb);
+
+    py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
+#endif
+
     // check whether this is a SyntaxError: unexpected EOF while parsing
     // that would indicate that the command is not complete and needs more
     // input til it's completed
-    PyErr_Fetch(&exc, &value, &tb);
-    PyErr_NormalizeException(&exc, &value, &tb);
-    if (PyErr_GivenExceptionMatches(exc, PyExc_SyntaxError) ||
-        PyErr_GivenExceptionMatches(exc, PyExc_IndentationError)) {
+    if (PyErr_GivenExceptionMatches(exc_value.get(), PyExc_SyntaxError) ||
+        PyErr_GivenExceptionMatches(exc_value.get(), PyExc_IndentationError)) {
       // If there's no more input then the interpreter should not continue in
       // continued mode so any error should bubble up
       if (!flush) {
         const char *msg;
         PyObject *obj;
-        const py::Release args{PyObject_GetAttrString(value, "args")};
+        const py::Release args{PyObject_GetAttrString(exc_value.get(), "args")};
 
         if (args && PyTuple_Check(args.get()) &&
             PyArg_ParseTuple(args.get(), "sO", &msg, &obj)) {
@@ -880,7 +898,13 @@ Value Python_context::execute_interactive(const std::string &code,
         }
       }
     }
-    PyErr_Restore(exc, value, tb);
+
+#if PY_VERSION_HEX >= 0x030c0000
+    PyErr_SetRaisedException(exc_value.release());
+#else
+    PyErr_Restore(exc_type.release(), exc_value.release(), exc_tb.release());
+#endif
+
     if (r_state != Input_state::Ok)
       PyErr_Clear();
     else
@@ -909,7 +933,7 @@ void Python_context::get_members_of(
 
   if (!members || !PySequence_Check(members.get())) return;
 
-  for (int i = 0, c = PySequence_Size(members.get()); i < c; i++) {
+  for (Py_ssize_t i = 0, c = PySequence_Size(members.get()); i < c; i++) {
     py::Release m{PySequence_ITEM(members.get(), i)};
     std::string s;
 
@@ -979,16 +1003,16 @@ void Python_context::set_python_error(const shcore::Exception &exc,
                                       const std::string &location) {
   std::string error_message;
 
-  std::string type = exc.error()->get_string("type", "");
-  std::string message = exc.error()->get_string("message", "");
   int64_t code = exc.error()->get_int("code", -1);
-  std::string error_location = exc.error()->get_string("location", "");
-
   if (code > 0) {
     set_shell_error(exc);
     return;
   }
 
+  auto type = exc.error()->get_string("type", "");
+  auto message = exc.error()->get_string("message", "");
+  auto error_location = exc.error()->get_string("location", "");
+
   if (error_location.empty()) error_location = location;
 
   PyObject *exctype = PyExc_RuntimeError;
@@ -1039,6 +1063,29 @@ void Python_context::set_python_error(PyObject *obj,
   PyErr_SetString(obj, location.c_str());
 }
 
+void Python_context::set_python_error(const std::string &module,
+                                      const std::string &exception,
+                                      const std::string &location) {
+  py::Release py_module{PyImport_ImportModule(module.c_str())};
+  if (!py_module) {
+    PyErr_Clear();
+    throw std::runtime_error(shcore::str_format(
+        "Could not import Python '%s' module", module.c_str()));
+  }
+
+  PyObject *py_module_dict = PyModule_GetDict(py_module.get());
+
+  PyObject *except_item =
+      PyDict_GetItemString(py_module_dict, exception.c_str());
+  if (!except_item) {
+    throw std::runtime_error(
+        shcore::str_format("Could not find type '%s' in '%s' module",
+                           exception.c_str(), module.c_str()));
+  }
+
+  set_python_error(except_item, location);
+}
+
 bool Python_context::pystring_to_string(PyObject *strobject,
                                         std::string *result, bool convert) {
   if (PyUnicode_Check(strobject)) {
@@ -1174,9 +1221,19 @@ PyObject *Python_context::shell_stdout(PyObject *self, PyObject *args) {
 }
 
 PyObject *Python_context::shell_stdout_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
+}
+
+PyObject *Python_context::shell_stdout_fileno(PyObject *, PyObject *) {
+  try {
+    Python_context::set_python_error("io", "UnsupportedOperation",
+                                     "Method not supported.");
+  } catch (...) {
+    set_python_error(PyExc_IOError, "Method not supported.");
+  }
+
+  return nullptr;
 }
 
 PyObject *Python_context::shell_stderr(PyObject *self, PyObject *args) {
@@ -1184,9 +1241,19 @@ PyObject *Python_context::shell_stderr(PyObject *self, PyObject *args) {
 }
 
 PyObject *Python_context::shell_stderr_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
+}
+
+PyObject *Python_context::shell_stderr_fileno(PyObject *, PyObject *) {
+  try {
+    Python_context::set_python_error("io", "UnsupportedOperation",
+                                     "Method not supported.");
+  } catch (...) {
+    set_python_error(PyExc_IOError, "Method not supported.");
+  }
+
+  return nullptr;
 }
 
 PyObject *Python_context::shell_flush_stderr(PyObject *, PyObject *) {
@@ -1258,18 +1325,15 @@ PyObject *Python_context::shell_stdin_readline(PyObject *, PyObject *) {
 }
 
 PyObject *Python_context::shell_stdin_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
 }
 
 PyObject *Python_context::shell_interactive_eval_hook(PyObject *,
                                                       PyObject *args) {
-  Python_context *ctx;
-  std::string text;
-
   shcore::Scoped_naming_style ns(shcore::NamingStyle::LowerCaseUnderscores);
 
+  Python_context *ctx;
   if (!(ctx = Python_context::get_and_check())) return nullptr;
 
   if (PyTuple_Size(args) == 1) {
@@ -1292,6 +1356,7 @@ PyMethodDef Python_context::ShellStdErrMethods[] = {
      "Write an error string in the SHELL shell."},
     {"flush", &Python_context::shell_flush_stderr, METH_NOARGS, ""},
     {"isatty", &Python_context::shell_stderr_isatty, METH_NOARGS, ""},
+    {"fileno", &Python_context::shell_stderr_fileno, METH_NOARGS, ""},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1300,6 +1365,7 @@ PyMethodDef Python_context::ShellStdOutMethods[] = {
      "Write a string in the SHELL shell."},
     {"flush", &Python_context::shell_flush, METH_NOARGS, ""},
     {"isatty", &Python_context::shell_stdout_isatty, METH_NOARGS, ""},
+    {"fileno", &Python_context::shell_stdout_fileno, METH_NOARGS, ""},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1317,11 +1383,9 @@ PyMethodDef Python_context::ShellPythonSupportMethods[] = {
      METH_VARARGS,
      "Custom displayhook to capture interactive expr evaluation results."},
     {"raw_input", &Python_context::shell_raw_input, METH_VARARGS,
-     "raw_input([prompt]) -> string\n"
-     "\n"
-     "Read a string from standard input.  The trailing newline is stripped.\n"
-     "If the user hits EOF (Unix: Ctl-D, Windows: Ctl-Z+Return), raise "
-     "EOFError.\n"},
+     "raw_input([prompt]) -> string\n\nRead a string from standard input.  The "
+     "trailing newline is stripped.\nIf the user hits EOF (Unix: Ctl-D, "
+     "Windows: Ctl-Z+Return), raise EOFError.\n"},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1334,7 +1398,7 @@ static void add_module_members(
   for (const auto &member_name : module->get_members()) {
     shcore::Value member = module->get_member_advanced(member_name);
     py::Release value;
-    if (member.type == shcore::Function)
+    if (member.get_type() == shcore::Function)
       value = wrap(module, member_name);
     else
       value = ctx->convert(member);
@@ -1409,6 +1473,11 @@ void Python_context::register_mysqlsh_module() {
     assert(0);
   }
 
+  {
+    const py::Release path{PyString_FromString(g_mysqlsh_path)};
+    PyDict_SetItemString(py_mysqlsh_dict, "executable", path.get());
+  }
+
   _mysqlsh_globals =
       py::Store{PyDict_GetItemString(py_mysqlsh_dict, "globals")};
   assert(_mysqlsh_globals);
@@ -1716,40 +1785,46 @@ namespace {
 bool get_code_and_msg(int *out_code, std::string *out_msg) {
   bool ret = false;
 
-  PyObject *exc = nullptr;
-  PyObject *value = nullptr;
-  PyObject *tb = nullptr;
+#if PY_VERSION_HEX >= 0x030c0000
+  py::Release exc_value{PyErr_GetRaisedException()};
+#else
+  PyObject *type, *value, *tb;
+
+  PyErr_Fetch(&type, &value, &tb);
+  PyErr_NormalizeException(&type, &value, &tb);
+
+  py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
+#endif
 
-  PyErr_Fetch(&exc, &value, &tb);
   {
-    PyErr_NormalizeException(&exc, &value, &tb);
+    py::Release args{PyObject_GetAttrString(exc_value.get(), "args")};
 
-    PyObject *args = PyObject_GetAttrString(value, "args");
-    if (args && PyTuple_Check(args) && PyTuple_GET_SIZE(args) == 2) {
+    if (args && PyTuple_Check(args.get()) &&
+        PyTuple_GET_SIZE(args.get()) == 2) {
       const char *msg;
 
-      if (PyTuple_GetItem(args, 0) == Py_None) {
+      if (PyTuple_GetItem(args.get(), 0) == Py_None) {
         PyObject *dummy;
         *out_code = 0;
-        if (PyArg_ParseTuple(args, "Os", &dummy, &msg)) {
+        if (PyArg_ParseTuple(args.get(), "Os", &dummy, &msg) && msg) {
           ret = true;
           *out_msg = msg;
         }
       } else {
-        if (PyArg_ParseTuple(args, "is", out_code, &msg) && msg) {
+        if (PyArg_ParseTuple(args.get(), "is", out_code, &msg) && msg) {
           ret = true;
-          *out_msg = std::string(msg);
+          *out_msg = msg;
         }
       }
     }
   }
 
-  if (ret) {
-    Py_XDECREF(exc);
-    Py_XDECREF(value);
-    Py_XDECREF(tb);
-  } else {
-    PyErr_Restore(exc, value, tb);
+  if (!ret) {
+#if PY_VERSION_HEX >= 0x030c0000
+    PyErr_SetRaisedException(exc_value.release());
+#else
+    PyErr_Restore(exc_type.release(), exc_value.release(), exc_tb.release());
+#endif
   }
 
   return ret;
@@ -1782,15 +1857,7 @@ void Python_context::throw_if_mysqlsh_error() {
   }
 }
 
-void Python_context::clear_exception() {
-  PyObject *exc, *value, *tb;
-
-  PyErr_Fetch(&exc, &value, &tb);
-
-  Py_XDECREF(exc);
-  Py_XDECREF(value);
-  Py_XDECREF(tb);
-}
+void Python_context::clear_exception() { PyErr_Clear(); }
 
 std::string Python_context::fetch_and_clear_exception() {
   if (!PyErr_Occurred()) return {};
@@ -1798,53 +1865,61 @@ std::string Python_context::fetch_and_clear_exception() {
   std::string exception;
   shcore::Scoped_naming_style ns(shcore::NamingStyle::LowerCaseUnderscores);
 
-  PyObject *exc = nullptr;
-  PyObject *value = nullptr;
-  PyObject *tb = nullptr;
+#if PY_VERSION_HEX >= 0x030c0000
+  py::Release exc_value{PyErr_GetRaisedException()};
+  py::Release exc_tb{PyException_GetTraceback(exc_value.get())};
+#else
+  PyObject *type, *value, *tb;
 
-  PyErr_Fetch(&exc, &value, &tb);
-  PyErr_NormalizeException(&exc, &value, &tb);
+  PyErr_Fetch(&type, &value, &tb);
+  PyErr_NormalizeException(&type, &value, &tb);
+
+  py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
+#endif
 
   {
-    PyObject *str = PyObject_Str(value);
+    py::Release str{PyObject_Str(exc_value.get())};
     pystring_to_string(str, &exception);
-    Py_XDECREF(str);
   }
 
-  if (nullptr != tb) {
-    PyObject *traceback_module = PyImport_ImportModule("traceback");
+  if (!exc_tb) {
+    return exception;
+  }
 
-    if (nullptr != traceback_module) {
-      PyObject *format_exception =
-          PyObject_GetAttrString(traceback_module, "format_exception");
+#if PY_VERSION_HEX >= 0x030c0000
+  // docs for traceback.print_exception()/format_exception() say:
+  // Since Python 3.10, instead of passing value and tb, an exception object can
+  // be passed as the first argument.
+  // in our case, the first argument is exc_type
+  py::Release exc_type = std::move(exc_value);
+  exc_tb.reset();
+#endif
 
-      if (nullptr != format_exception && PyCallable_Check(format_exception)) {
-        PyObject *backtrace = PyObject_CallFunctionObjArgs(
-            format_exception, exc, value, tb, nullptr);
+  py::Release traceback_module{PyImport_ImportModule("traceback")};
 
-        if (nullptr != backtrace && PyList_Check(backtrace)) {
-          exception = "\n";
+  if (!traceback_module) {
+    return exception;
+  }
 
-          for (Py_ssize_t c = PyList_Size(backtrace), i = 0; i < c; ++i) {
-            std::string item;
-            pystring_to_string(PyList_GetItem(backtrace, i), &item);
-            exception += item;
-          }
-        }
+  py::Release format_exception{
+      PyObject_GetAttrString(traceback_module.get(), "format_exception")};
 
-        Py_XDECREF(backtrace);
+  if (format_exception && PyCallable_Check(format_exception.get())) {
+    py::Release backtrace{
+        PyObject_CallFunctionObjArgs(format_exception.get(), exc_type.get(),
+                                     exc_value.get(), exc_tb.get(), nullptr)};
+
+    if (backtrace && PyList_Check(backtrace.get())) {
+      exception = "\n";
+
+      for (Py_ssize_t c = PyList_Size(backtrace.get()), i = 0; i < c; ++i) {
+        std::string item;
+        pystring_to_string(PyList_GetItem(backtrace.get(), i), &item);
+        exception += item;
       }
-
-      Py_XDECREF(format_exception);
     }
-
-    Py_XDECREF(traceback_module);
   }
 
-  Py_XDECREF(exc);
-  Py_XDECREF(value);
-  Py_XDECREF(tb);
-
   return exception;
 }
 
