@@ -1,15 +1,17 @@
-# Copyright (c) 2021, 2023, Oracle and/or its affiliates.
+# Copyright (c) 2021, 2024, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
 # as published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
-# but not limited to OpenSSL) that is licensed under separate terms, as
-# designated in a particular file or component or in included license
+# This program is designed to work with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
 # documentation.  The authors of MySQL hereby grant you an additional
 # permission to link the program and your derivative works with the
-# separately licensed software that they have included with MySQL.
+# separately licensed software that they have either included with
+# the program or referenced in the documentation.
+#
 # This program is distributed in the hope that it will be useful,  but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -341,7 +343,10 @@ def dump_diff(f, key_label, instance_labels, diff, header):
     for k, v in diff:
         line = [k.ljust(column_widths[0])]
         for i, value in enumerate(v):
-            line.append(value.ljust(column_widths[1+i]))
+            if value:
+                line.append(value.ljust(column_widths[1+i]))
+            else:
+                line.append("NULL".ljust(column_widths[1+i]))
         f.write((" | ".join(line) + "\n").encode("utf-8"))
 
 
@@ -620,7 +625,7 @@ def execute_profiled_query(zf: zipfile.ZipFile, prefix: str, helper_session, que
         "Result Fetch Time": (fetch_end - fetch_start),
         "Query": query,
         "Warnings": normalize(r.get_warnings()),
-        "Affected Rows": r.get_affected_row_count(),
+        "Affected Rows": r.get_affected_items_count(),
         "Result Rows": row_count
     }
     if hasattr(r, "get_info"):
