@@ -29,6 +29,10 @@
 #include "unittest/gtest_clean.h"
 #include "unittest/test_utils.h"
 
+namespace {
+
+#ifdef USE_MYSQLX_FULL_PROTO
+
 template <typename Message_type>
 std::string message_to_text(const Message_type &msg) {
   std::string result;
@@ -38,6 +42,14 @@ std::string message_to_text(const Message_type &msg) {
   return msg.GetDescriptor()->full_name() + " { " + result + " }";
 }
 
+#else  //! USE_MYSQLX_FULL_PROTO
+
+std::string message_to_text(const xcl::XProtocol::Message &msg) {
+  return msg.GetTypeName() + " { " + msg.DebugString() + " }";
+}
+
+#endif  // !USE_MYSQLX_FULL_PROTO
+
 void print_message(const std::string &direction,
                    const xcl::XProtocol::Message &msg) {
   std::cout << direction << "\t" << msg.ByteSizeLong() + 1 << "\t"
@@ -54,8 +66,6 @@ xcl::Handler_result trace_send_messages(
   return xcl::Handler_result::Continue;
 }
 
-extern mysqlshdk::utils::Version g_target_server_version;
-
 xcl::Handler_result trace_received_messages(
     xcl::XProtocol * /* protocol */,
     const xcl::XProtocol::Server_message_type_id /* msg_id */,
@@ -66,7 +76,7 @@ xcl::Handler_result trace_received_messages(
   return xcl::Handler_result::Continue;
 }
 
-void enable_trace(xcl::XSession *sess) {
+[[maybe_unused]] void enable_trace(xcl::XSession *sess) {
   auto &protocol = sess->get_protocol();
 
   protocol.add_received_message_handler(
@@ -84,6 +94,10 @@ void enable_trace(xcl::XSession *sess) {
       });
 }
 
+}  // namespace
+
+extern mysqlshdk::utils::Version g_target_server_version;
+
 namespace mysqlsh {
 namespace mysqlx {
 
