@@ -25,6 +25,7 @@
 
 #include "unittest/gtest_clean.h"
 
+#include "ext/linenoise-ng/include/linenoise.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
 #include "mysqlshdk/libs/utils/version.h"
@@ -35,6 +36,8 @@
 
 class Mysqlsh_misc : public tests::Command_line_test {};
 
+#ifdef USE_MYSQLX_FULL_PROTO
+
 TEST_F(Mysqlsh_misc, trace_proto) {
   execute({_mysqlsh, _uri.c_str(), "--trace-proto", "--sql", "-e", "select 1",
            nullptr});
@@ -76,10 +79,12 @@ TEST_F(Mysqlsh_misc, trace_proto) {
   }
 }
 
+#endif
+
 TEST_F(Mysqlsh_misc, load_builtin_modules) {
 // Regression test for Bug #26174373
 // Built-in modules should auto-load in non-interactive sessions too
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   wipe_out();
   execute({_mysqlsh, "--js", "-e", "println(mysqlx)", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("<mysqlx>");
@@ -96,7 +101,7 @@ TEST_F(Mysqlsh_misc, load_builtin_modules) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("<module 'mysqlsh.mysql' (built-in)>");
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Mysqlsh_misc, connection_attribute) {
   // Regression test for Bug #24735491
   // MYSQL SHELL DOESN'T SET CONNECTION ATTRIBUTES
@@ -154,7 +159,7 @@ TEST_F(Mysqlsh_misc, warning_insecure_password) {
   wipe_out();
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Mysqlsh_misc, autocompletion_options) {
   execute({_mysqlsh, "--js", "-e",
            "println(shell.options['devapi.dbObjectHandles'], "
@@ -200,7 +205,7 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   } catch (...) {
   }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   execute({_mysqlsh, "-f", "bla.js", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("JavaScript works");
   wipe_out();
@@ -222,12 +227,13 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("Python works!");
   wipe_out();
 
-#ifdef HAVE_V8
-  // will exec using JS - OK
+#ifdef HAVE_JS
+  // will exec using SQL (default) - ERROR
   execute({_mysqlsh, "-f", "js.foo", nullptr});
-  MY_EXPECT_CMD_OUTPUT_CONTAINS("JS works!");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Not connected");
   wipe_out();
 
+  // will exec using JS - OK
   execute({_mysqlsh, "--js", "-f", "js.foo", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("JS works!");
   wipe_out();
@@ -245,7 +251,7 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("Python works!");
   wipe_out();
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   // now change the default startup mode and persist it
   // Bug#27861407  SHELL DOESN'T EXECUTE SCRIPTS USING CORRECT LANGUAGE
   execute({_mysqlsh, "--js", "-e",
@@ -260,7 +266,7 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("Python works");
   wipe_out();
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   execute({_mysqlsh, "-f", "js.foo", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("JS works!");
   wipe_out();
@@ -274,7 +280,7 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("Not connected");
   wipe_out();
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   // again with Python as default
   execute({_mysqlsh, "--js", "-e",
            "shell.options.setPersist('defaultMode', 'py')", nullptr});
@@ -287,7 +293,7 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   MY_EXPECT_CMD_OUTPUT_CONTAINS("Python works");
   wipe_out();
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   execute({_mysqlsh, "-f", "js.foo", nullptr});
   wipe_out();
 #endif
@@ -356,3 +362,19 @@ print(sys.argv)
   } catch (...) {
   }
 }
+
+TEST_F(Mysqlsh_misc, invalid_unicode_linoise_custom_command) {
+  linenoiseRegisterCustomCommand(
+      "\x18\x18",  // CTRL-X, CTRL-X
+      [](const char *, void *, char **) { return -1; }, nullptr);
+
+  int specialValue = 1048;    // 0000 0100 0001 1000, russian unicode shift+B,
+  int sepcialValue2 = 65304;  // 1111 1111 0001 1000, japanese unicode '8'
+  int correctValue = 0x18;    // 0000 0000 0001 1000, CTRL-X
+
+  EXPECT_FALSE(linonoiseTestExtendedCharacter(specialValue));
+  EXPECT_FALSE(linonoiseTestExtendedCharacter(correctValue, specialValue));
+
+  EXPECT_FALSE(linonoiseTestExtendedCharacter(sepcialValue2));
+  EXPECT_FALSE(linonoiseTestExtendedCharacter(correctValue, sepcialValue2));
+}
