@@ -52,7 +52,7 @@ class Instance_test : public tests::Shell_base_test {
 
     _session.reset(&session, DoNotDelete());
 
-    _connection_options = shcore::get_connection_options(_mysql_uri);
+    _connection_options = mysqlshdk::db::Connection_options(_mysql_uri);
   }
 };
 
@@ -1099,38 +1099,6 @@ TEST_F(Instance_test, create_user_ssl_options) {
   _session->close();
 }
 
-TEST_F(Instance_test, get_user_privileges_user_does_not_exist) {
-  EXPECT_CALL(session, do_connect(_connection_options));
-  EXPECT_CALL(session, is_open()).WillOnce(Return(false));
-  const mysqlshdk::db::Connection_options opts;
-  EXPECT_CALL(session, get_connection_options()).WillOnce(ReturnRef(opts));
-  _session->connect(_connection_options);
-
-  // Check non existing user.
-  testing::user_privileges::Setup_options options;
-
-  options.user = "notexist_user";
-  options.host = "notexist_host";
-  options.user_exists = false;
-  // Simulate 5.7 version is used (not relevant here, 5.7 used to avoid
-  // executing additional queries to update the ALL privileges list).
-  options.version = mysqlshdk::utils::Version(5, 7, 28);
-
-  testing::user_privileges::setup(options, &session);
-
-  mysqlshdk::mysql::Instance instance(_session);
-
-  auto up = instance.get_user_privileges(options.user, options.host);
-
-  ASSERT_TRUE(nullptr != up);
-
-  EXPECT_FALSE(up->user_exists());
-
-  EXPECT_CALL(session, do_close());
-  EXPECT_CALL(session, is_open()).WillOnce(Return(false));
-  _session->close();
-}
-
 TEST_F(Instance_test, get_user_privileges_user_exists) {
   EXPECT_CALL(session, do_connect(_connection_options));
   EXPECT_CALL(session, is_open()).WillOnce(Return(false));
@@ -1336,16 +1304,6 @@ TEST_F(Instance_test, is_set_persist_supported) {
   EXPECT_FALSE(!res.has_value());
   EXPECT_TRUE(*res);
 
-  mysqlshdk::mysql::Instance instance_57(_session);
-
-  // Simulate 5.7 version is used.
-  EXPECT_CALL(session, get_server_version())
-      .WillRepeatedly(Return(mysqlshdk::utils::Version(5, 7, 24)));
-
-  // Set is not supported.
-  res = instance_57.is_set_persist_supported();
-  EXPECT_TRUE(!res.has_value());
-
   EXPECT_CALL(session, do_close());
   EXPECT_CALL(session, is_open()).WillOnce(Return(false));
   _session->close();
@@ -1500,6 +1458,20 @@ TEST_F(Instance_test, get_current_user) {
                    "example.com");
 }
 
+TEST_F(Instance_test, generate_uuid) {
+  mysqlshdk::mysql::Instance instance(_session);
+
+  session.expect_query("SELECT UUID()")
+      .then_return({{
+          "",
+          {"UUID()"},
+          {Type::String},
+          {{"259df69c-ae11-11ed-9515-8e644b4d9f38"}},
+      }});
+
+  instance.generate_uuid();
+}
+
 TEST_F(Instance_test, session_limits) {
   mysqlshdk::mysql::Instance instance(_session);
   session
