@@ -79,37 +79,9 @@ Process_type current_process_type() {
 
 }  // namespace
 
-class Interrupt_tester : public shcore::Interrupt_helper {
- public:
-  void setup() override {
-    setup_ = true;
-    unblocked_ = 1;
-  }
-
-  void block() override {
-    // we're not supposed to get called while we're already blocked
-    unblocked_++;
-  }
-
-  void unblock(bool /* clear_pending */) override { unblocked_--; }
-
-  int unblocked_ = 0;
-  bool setup_ = false;
-};
-
-static Interrupt_tester interrupt_tester;
-
 // The following tests check interruption of the shell in batch mode
-
 class Interrupt_mysqlsh : public tests::Command_line_test {
- public:
-  Interrupt_mysqlsh() {
-    m_current_interrupt = shcore::Interrupts::create(&interrupt_tester);
-  }
-
  protected:
-  std::shared_ptr<shcore::Interrupts> m_current_interrupt;
-
   static void SetUpTestCase() {
     run_script_classic(
         {"drop schema if exists itst;", "create schema if not exists itst;",
@@ -309,14 +281,13 @@ class Interrupt_mysqlsh : public tests::Command_line_test {
   }
 
   void SetUp() override {
-    m_current_interrupt->setup();
     tests::Command_line_test::SetUp();
 
     kill_thread = std::thread();
 
     session.reset(new mysqlsh::mysql::ClassicSession());
 
-    auto connection_options = shcore::get_connection_options(_mysql_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_mysql_uri);
     session->connect(connection_options);
   }
 
@@ -350,7 +321,7 @@ class Interrupt_mysqlsh : public tests::Command_line_test {
   std::thread kill_thread;
 };
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Interrupt_mysqlsh, crud_js_x_cli) {
   // FR8-b-8 FR9-b-9
   kill_on_ready();
@@ -387,7 +358,7 @@ TEST_F(Interrupt_mysqlsh, py_cli) {
   EXPECT_EQ(130, rc);
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Interrupt_mysqlsh, js_cli) {
   // FR8-b-8 FR9-b-8
   kill_on_ready();
@@ -486,7 +457,7 @@ TEST_F(Interrupt_mysqlsh, py_file_batch) {
   TEST_INTERRUPT_SCRIPT_B(_mysql_uri.c_str(), "--py", "test_queryc.py");
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Interrupt_mysqlsh, js_file_interactive) {
   // Test cases for FR8-a-2 FR8-b-2 FR9-a-2 FR9-b-2
   const char *expect = "Script execution interrupted by user";
@@ -563,7 +534,6 @@ TEST_F(Interrupt_mysqlsh, dba_js) {
 //------------------------------------------------------------------------------
 
 TEST_F(Interrupt_mysqlsh, sql_cli) {
-  mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
   // FR8-a-7 FR9-b-7
   kill_on_ready();
 
@@ -580,7 +550,6 @@ TEST_F(Interrupt_mysqlsh, sql_cli) {
 }
 
 TEST_F(Interrupt_mysqlsh, sqlx_cli) {
-  mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
   // FR8-b-7 FR9-b-7
   kill_on_ready();
 
@@ -674,7 +643,7 @@ TEST_F(Interrupt_mysqlsh, json_import) {
   const char *expect = "JSON documents import cancelled.";
   const char *unexpect = nullptr;
   const int exitcode = 0;
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   TEST_INTERRUPT_ON_MSG_SCRIPT_I(_uri.c_str(), "--js", "test_jsonimport.js",
                                  "Importing from file ");
 #else
@@ -729,7 +698,7 @@ TEST_F(Interrupt_mysqlsh, prompt_password_from_stdin) {
   test_prompt(false, true, true);
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Interrupt_mysqlsh, js_prompt) { test_prompt(true, false, false); }
 
 TEST_F(Interrupt_mysqlsh, js_prompt_password) {
@@ -743,7 +712,7 @@ TEST_F(Interrupt_mysqlsh, js_prompt_password) {
 TEST_F(Interrupt_mysqlsh, js_prompt_password_from_stdin) {
   test_prompt(true, true, true);
 }
-#endif  // HAVE_V8
+#endif  // HAVE_JS
 
 }  // namespace mysqlsh
 
