@@ -95,15 +95,7 @@ testutil.waitMemberState(__mysql_sandbox_port3, "ONLINE");
 scene.make_no_quorum([__mysql_sandbox_port1])
 cluster.setInstanceOption(__sandbox_uri2, "memberWeight", 25);
 
-//@<ERR> WL#11465: Error when executing setInstanceOption on a cluster with no visible quorum 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
-testutil.startSandbox(__mysql_sandbox_port3);
-cluster.rejoinInstance(__sandbox_uri3);
-testutil.waitMemberState(__mysql_sandbox_port3, "ONLINE");
-
-scene.make_no_quorum([__mysql_sandbox_port1])
-cluster.setInstanceOption(__sandbox_uri2, "memberWeight", 25);
-
-//@ WL#11465: Re-create the cluster
+//@<> WL#11465: Re-create the cluster
 scene.destroy();
 var scene = new ClusterScenario([__mysql_sandbox_port1, __mysql_sandbox_port2, __mysql_sandbox_port3]);
 var cluster = scene.cluster
@@ -114,13 +106,14 @@ var cluster = scene.cluster
 // - exitStateAction
 // - memberWeight
 
-//@<ERR> WL#11465: setInstanceOption label with invalid value for label 1
-cluster.setInstanceOption(__sandbox_uri2, "label", "-0_a");
+//@<> WL#11465: setInstanceOption label with invalid value for label 1
+EXPECT_THROWS(function() { cluster.setInstanceOption(__sandbox_uri2, "label", "-0_a"); }, "The label can only start with an alphanumeric or the '_' character.");
 
-//@<ERR> WL#11465: setInstanceOption label with invalid value for label 2
+//@<> WL#11465: setInstanceOption label with invalid value for label 2
 var __invalid_label = hostname + ":" + __mysql_sandbox_port1;
 
-cluster.setInstanceOption(__sandbox_uri2, "label", __invalid_label);
+EXPECT_THROWS(function() { cluster.setInstanceOption(__sandbox_uri2, "label", __invalid_label); }, `Instance '${hostname}:${__mysql_sandbox_port1}' is already using label '${__invalid_label}'.`);
+
 
 //@<OUT> WL#11465: setInstanceOption label
 cluster.setInstanceOption(__sandbox_uri2, "label", "newLabel");
@@ -131,10 +124,7 @@ shell.connect(__sandbox_uri2);
 var __address2 = hostname + ":" + __mysql_sandbox_port2;
 print_metadata_instance_label(session, __address2);
 
-//@<OUT> WL#11465: setInstanceOption memberWeight {VER(>=8.0.0)}
-cluster.setInstanceOption(__sandbox_uri2, "memberWeight", 25);
-
-//@<OUT> WL#11465: setInstanceOption memberWeight 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
+//@<OUT> WL#11465: setInstanceOption memberWeight
 cluster.setInstanceOption(__sandbox_uri2, "memberWeight", 25);
 
 //@<OUT> WL#11465: memberWeight label changed correctly
@@ -143,10 +133,7 @@ print(get_sysvar(session, "group_replication_member_weight"));
 //@<ERR> WL#11465: setInstanceOption exitStateAction with invalid value
 cluster.setInstanceOption(__sandbox_uri2, "exitStateAction", "ABORT");
 
-//@<OUT> WL#11465: setInstanceOption exitStateAction {VER(>=8.0.0)}
-cluster.setInstanceOption(__sandbox_uri2, "exitStateAction", "ABORT_SERVER");
-
-//@<OUT> WL#11465: setInstanceOption exitStateAction 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
+//@<OUT> WL#11465: setInstanceOption exitStateAction
 cluster.setInstanceOption(__sandbox_uri2, "exitStateAction", "ABORT_SERVER");
 
 //@<OUT> WL#11465: exitStateAction label changed correctly
@@ -179,8 +166,10 @@ print(get_sysvar(__mysql_sandbox_port3, "group_replication_autorejoin_tries", "P
 //@<> Check that setInstanceOption works if you have quorum and the instance reachable but not online
 // keep instance 3 in RECOVERING state by setting a wrong recovery user.
 session3 = shell.connect(__sandbox_uri3);
-session3.runSql("CHANGE MASTER TO MASTER_USER = 'not_exist', MASTER_PASSWORD = '' FOR CHANNEL 'group_replication_recovery'");
+session3.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER = 'not_exist', " + get_replication_option_keyword() + "_PASSWORD = '' FOR CHANNEL 'group_replication_recovery'");
 session3.runSql("STOP GROUP_REPLICATION");
+session1 = mysql.getSession(__sandbox_uri1);
+session1.runSql("create schema foo");
 session3.runSql("START GROUP_REPLICATION");
 testutil.waitMemberState(__mysql_sandbox_port3, "RECOVERING");
 cluster.setInstanceOption(__sandbox_uri3, "memberWeight", 28);
@@ -349,6 +338,43 @@ testutil.waitMemberState(__mysql_sandbox_port3, "(MISSING),UNREACHABLE");
 EXPECT_THROWS_TYPE(function(){cluster.setInstanceOption(__sandbox_uri1, "tag:test1", "test")}, "There is no quorum to perform the operation", "MYSQLSH");
 EXPECT_THROWS_TYPE(function(){cluster.setInstanceOption(__sandbox_uri2, "tag:test1", "test")}, "There is no quorum to perform the operation", "MYSQLSH");
 
+//@<> setInstanceOption() must only accept setting the tags `_hidden` or `_disconnect_existing_sessions_when_hidden`, the options `label` or `readReplicaReplicationSources`, and no other option if the target instance is a Read Replica //@ {VER(>=8.0.23)}
+cluster.forceQuorumUsingPartitionOf(__sandbox_uri1);
+testutil.startSandbox(__mysql_sandbox_port2);
+testutil.waitMemberState(__mysql_sandbox_port2, "ONLINE");
+cluster.removeInstance(__endpoint2)
+cluster.addReplicaInstance(__endpoint2);
+
+EXPECT_THROWS_TYPE(function() { cluster.setInstanceOption(__sandbox_uri2,"exitStateAction", "ABORT_SERVER")}, "The instance '" + __sandbox2 + "' does not support this operation.", "RuntimeError");
+EXPECT_OUTPUT_CONTAINS(`The option 'exitStateAction' is not supported for Read-Replicas.`);
+
+EXPECT_THROWS_TYPE(function() { cluster.setInstanceOption(__sandbox_uri2,"memberWeight", 10)}, "The instance '" + __sandbox2 + "' does not support this operation.", "RuntimeError");
+EXPECT_OUTPUT_CONTAINS(`The option 'memberWeight' is not supported for Read-Replicas.`);
+
+EXPECT_THROWS_TYPE(function() { cluster.setInstanceOption(__sandbox_uri2,"autoRejoinTries", 1)}, "The instance '" + __sandbox2 + "' does not support this operation.", "RuntimeError");
+EXPECT_OUTPUT_CONTAINS(`The option 'autoRejoinTries' is not supported for Read-Replicas.`);
+
+EXPECT_THROWS_TYPE(function() { cluster.setInstanceOption(__sandbox_uri2,"ipAllowlist", "127.0.0.1")}, "The instance '" + __sandbox2 + "' does not support this operation.", "RuntimeError");
+EXPECT_OUTPUT_CONTAINS(`The option 'ipAllowlist' is not supported for Read-Replicas.`);
+
+EXPECT_NO_THROWS(function() {cluster.setInstanceOption(__sandbox_uri2, "tag:_hidden", false); });
+
+EXPECT_ARRAY_CONTAINS("_hidden", Object.keys(get_tags_for_instance(cluster, __endpoint2)));
+EXPECT_TRUE(get_tags_for_instance(cluster, __endpoint2)["_hidden"] === false);
+
+EXPECT_NO_THROWS(function() {cluster.setInstanceOption(__sandbox_uri2, "tag:_disconnect_existing_sessions_when_hidden", true); });
+
+EXPECT_ARRAY_CONTAINS("_disconnect_existing_sessions_when_hidden", Object.keys(get_tags_for_instance(cluster, __endpoint2)));
+EXPECT_TRUE(get_tags_for_instance(cluster, __endpoint2)["_disconnect_existing_sessions_when_hidden"] === true);
+
+EXPECT_NO_THROWS(function() {cluster.setInstanceOption(__sandbox_uri2, "label", "newLabel"); });
+
+var status = cluster.status();
+var read_replica = status["defaultReplicaSet"]["topology"][__endpoint1]["readReplicas"]["newLabel"];
+EXPECT_EQ("READ_REPLICA", read_replica["role"]);
+
+EXPECT_NO_THROWS(function() {cluster.setInstanceOption(__sandbox_uri2, "replicationSources", "secondary"); });
+
 //@<>Finalization
 cluster.disconnect();
 session.close();
