@@ -111,12 +111,12 @@ EXPECT_EQ(0, session.runSql("SELECT COUNT(*) FROM mysql_innodb_cluster_metadata.
 testutil.deploySandbox(__mysql_sandbox_port4, "root", {report_host:hostname});
 cluster.addInstance(__sandbox_uri4);
 shell.connect(__sandbox_uri4);
-session.runSql("CHANGE MASTER TO MASTER_USER='custom_user', MASTER_PASSWORD='custom_user' FOR CHANNEL 'group_replication_recovery'");
+session.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER='custom_user', " + get_replication_option_keyword() + "_PASSWORD='custom_user' FOR CHANNEL 'group_replication_recovery'");
 var status = cluster.status();
 EXPECT_EQ("WARNING: Unsupported recovery account 'custom_user' has been found for instance '<<<hostname>>>:<<<__mysql_sandbox_port4>>>'. Operations such as Cluster.resetRecoveryAccountsPassword() and Cluster.addInstance() may fail. Please remove and add the instance back to the Cluster to ensure a supported recovery account is used.", status["defaultReplicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port4}`]["instanceErrors"][0])
 WIPE_STDOUT()
 cluster.rescan();
-EXPECT_STDOUT_CONTAINS("ERROR: Unsupported recovery account 'custom_user' has been found for instance '<<<hostname>>>:<<<__mysql_sandbox_port4>>>'. Operations such as <Cluster>.resetRecoveryAccountsPassword() and <Cluster>.addInstance() may fail. Please remove and add the instance back to the Cluster to ensure a supported recovery account is used.")
+EXPECT_STDOUT_CONTAINS(`Fixing incorrect recovery account 'custom_user' in instance '${hostname}:${__mysql_sandbox_port4}'`)
 
 //@<> clean up cluster - remove sandbox 4 from cluster
 //BUG#32157182
@@ -202,8 +202,16 @@ session1.runSql("create schema foobar");
 testutil.waitMemberState(__mysql_sandbox_port2, "(MISSING)");
 cluster.status();
 
+shell.options["dba.logSql"] = 1;
+WIPE_SHELL_LOG();
+
 cluster.status({extended:1});
 
+if (__version_num >= 80400) {
+    EXPECT_SHELL_LOG_NOT_CONTAINS("mysql.slave_master_info");
+    EXPECT_SHELL_LOG_NOT_CONTAINS("mysql.slave_relay_log_info");
+}
+
 //@<> reset sandbox2
 cluster.removeInstance(__sandbox_uri2, {force:1});
 session2.runSql("stop group_replication");
@@ -245,25 +253,10 @@ status = cluster.status();
 
 // ---- recovery status
 
-//@ recoveryChannel during recovery
-
+//@<> recoveryChannel with error
+// and instanceError with recovery channel error
 cluster.addInstance(__sandbox_uri3);
 
-// create the table in sb2 so we can lock it
-create_testdb(session2);
-session2.runSql("lock tables testdb.data read");
-
-session1.runSql("insert into testdb.data values (default, repeat('x', 200000))");
-
-cluster.addInstance(__sandbox_uri2, {waitRecovery:0});
-
-cluster.status({extended:1});
-
-session2.runSql("unlock tables");
-
-//@ recoveryChannel with error
-// and instanceError with recovery channel error
-cluster.removeInstance(__sandbox_uri2);
 reset_instance(session2);
 create_testdb(session2);
 session2.runSql("set global group_replication_recovery_retry_count=2");
@@ -278,47 +271,19 @@ session2.runSql("insert into testdb.data values (42, 'breakme')");
 session2.runSql("set sql_log_bin=1");
 session2.runSql("set global super_read_only=1");
 
-// freeze recovery when it tries to insert to this table
-session2.runSql("lock tables testdb.data read");
+// this ultimatly fails
+EXPECT_THROWS(function(){
+    cluster.addInstance(__sandbox_uri2);
+}, "Distributed recovery has failed");
 
-cluster.addInstance(__sandbox_uri2, {waitRecovery:0});
-
-session2.runSql("unlock tables");
-
-cluster.status();
-wait(200, 1, function(){return cluster.status().defaultReplicaSet.topology[hostname+":"+__mysql_sandbox_port2].status == "(MISSING)"; });
-
-cluster.status();
 // ---- other instanceErrors
 
-//@ instanceError with split-brain
-session2.runSql("stop group_replication");
-session2.runSql("set global group_replication_bootstrap_group=1");
+//@ instanceError with an instance that has its UUID changed
 
-if (__version_num >= 80027) {
-    session2.runSql("set global group_replication_communication_stack='xcom'");
-}
-
-session2.runSql("start group_replication");
-session2.runSql("set global group_replication_bootstrap_group=0");
-
-cluster.status();
-
-//@ instanceError with unmanaged member
-session2.runSql("stop group_replication");
-cluster.removeInstance(__sandbox_uri2, {force:1});
+// insert the instance correctly
 reset_instance(session2);
 cluster.addInstance(__sandbox_uri2);
-testutil.waitMemberState(__mysql_sandbox_port2, "ONLINE");
 
-session1.runSql("delete from mysql_innodb_cluster_metadata.instances where instance_name like ?", ["%"+__mysql_sandbox_port2]);
-
-cluster.status();
-
-// insert back the instance
-cluster.rescan({addInstances:"auto"});
-
-//@ instanceError with an instance that has its UUID changed
 shell.connect(__sandbox_uri1);
 cluster = dba.getCluster();
 
@@ -359,7 +324,7 @@ if (__version_num > 80000) {
     session.runSql(`GRANT CONNECTION_ADMIN ON *.* TO '${new_user}'\@'%'`);
 }
 
-session.runSql(`CHANGE MASTER TO MASTER_USER = '${new_user}', MASTER_PASSWORD = 'foo' FOR CHANNEL 'group_replication_recovery'`);
+session.runSql(`change ` + get_replication_source_keyword() + ` TO ` + get_replication_option_keyword() + `_USER = '${new_user}', ` + get_replication_option_keyword() + `_PASSWORD = 'foo' FOR CHANNEL 'group_replication_recovery'`);
 
 session.runSql(`DROP USER IF EXISTS '${old_user}'\@'%'`);
 session.runSql(`UPDATE mysql_innodb_cluster_metadata.instances SET attributes = json_set(COALESCE(attributes, '{}'), '$.recoveryAccountUser', '${new_user}') WHERE (mysql_server_uuid = CAST(@@server_uuid as char))`);
@@ -371,7 +336,7 @@ EXPECT_FALSE("instanceErrors" in status["defaultReplicaSet"]["topology"][`${host
 var stat = cluster.status();
 println(stat);
 
-//@<> Check replicationLag values {VER(>=8.0.0)}
+//@<> Check replicationLag values
 function get_lags(lags) {
   var stat = cluster.status();
   println(stat);
@@ -428,12 +393,12 @@ session3.runSql("UNLOCK TABLES");
 // If a cluster member with a version >= 8.0.23 doesn't have parallel-appliers enabled, that information
 // must be included in 'instanceErrors'
 
-//@<> BUG#32015164: preparation {VER(>=8.0.23)}
+//@<> BUG#32015164: preparation {VER(>=8.0.23) && VER(<8.4.0)}
 // Stop GR
 session2.runSql("STOP group_replication");
 testutil.waitMemberState(__mysql_sandbox_port2, "(MISSING)");
 // Disable parallel-appliers
-testutil.removeFromSandboxConf(__mysql_sandbox_port2, "binlog_transaction_dependency_tracking");
+testutil.changeSandboxConf(__mysql_sandbox_port2, "binlog_transaction_dependency_tracking", "COMMIT_ORDER");
 testutil.removeFromSandboxConf(__mysql_sandbox_port2, "slave_parallel_type");
 testutil.removeFromSandboxConf(__mysql_sandbox_port2, "slave_preserve_commit_order");
 testutil.removeFromSandboxConf(__mysql_sandbox_port2, "transaction_write_set_extraction");
@@ -443,17 +408,17 @@ testutil.restartSandbox(__mysql_sandbox_port2);
 // Let the instance rejoin the cluster
 testutil.waitMemberState(__mysql_sandbox_port2, "ONLINE");
 
-//@ BUG#32015164: instanceErrors must report missing parallel-appliers {VER(>=8.0.23)}
+//@ BUG#32015164: instanceErrors must report missing parallel-appliers {VER(>=8.0.23) && VER(<8.4.0)}
 cluster.status();
 
-//@<> BUG#32015164: fix with dba.configureInstance() {VER(>=8.0.23)}
+//@<> BUG#32015164: fix with dba.configureInstance() {VER(>=8.0.23) && VER(<8.4.0)}
 dba.configureInstance(__sandbox_uri2);
 
-//@<> BUG#32015164: rejoin instance after fix {VER(>=8.0.23)}
+//@<> BUG#32015164: rejoin instance after fix {VER(>=8.0.23) && VER(<8.4.0)}
 testutil.restartSandbox(__mysql_sandbox_port2);
 testutil.waitMemberState(__mysql_sandbox_port2, "ONLINE");
 
-//@<OUT> BUG#32015164: status should be fine now {VER(>=8.0.23)}
+//@<OUT> BUG#32015164: status should be fine now {VER(>=8.0.23) && VER(<8.4.0)}
 var stat = cluster.status();
 println(stat);
 
@@ -551,7 +516,7 @@ cluster.status()
 
 //@<> Check for OK_NO_TOLERANCE_PARTIAL (BUG#33989031)
 if (testutil.versionCheck(__version, "<", "8.0.0"))
-  dba.configureLocalInstance(__sandbox_uri3, {mycnfPath: mycnf3});
+  dba.configureInstance(__sandbox_uri3, {mycnfPath: mycnf3});
 
 testutil.stopSandbox(__mysql_sandbox_port3);
 testutil.waitMemberState(__mysql_sandbox_port3, "(MISSING)");
@@ -582,12 +547,6 @@ var cluster = dba.getCluster();
 //@<OUT> Status with a new primary
 cluster.status();
 
-//@<OUT> WL#13084 - TSF5_1: queryMembers option is deprecated (true).
-cluster.status({queryMembers:true});
-
-//@<OUT> WL#13084 - TSF5_1: queryMembers option is deprecated (false).
-cluster.status({queryMembers:false});
-
 // BUG#30401048: ERROR VERIFYING METADATA VERSION
 // Regression test to ensure that when a consistency level of "BEFORE", "AFTER" or
 // "BEFORE_AND_AFTER" was set in the cluster any other AdminAPI call can be executed
@@ -601,8 +560,10 @@ testutil.waitMemberState(__mysql_sandbox_port1, "ONLINE");
 //@<> BUG#30401048: Keep instance 1 in RECOVERING state {VER(>=8.0.14)}
 session.close();
 shell.connect(__sandbox_uri1);
-session.runSql("CHANGE MASTER TO MASTER_USER = 'not_exist', MASTER_PASSWORD = '' FOR CHANNEL 'group_replication_recovery'");
+session.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER = 'not_exist', " + get_replication_option_keyword() + "_PASSWORD = '' FOR CHANNEL 'group_replication_recovery'");
 session.runSql("STOP GROUP_REPLICATION");
+session2 = mysql.getSession(__sandbox_uri2);
+session2.runSql("create schema foo");
 session.runSql("START GROUP_REPLICATION");
 testutil.waitMemberState(__mysql_sandbox_port1, "RECOVERING");
 session.close();
