@@ -55,20 +55,12 @@ FUNCTIONS
             Validates and configures an instance for MySQL InnoDB Cluster
             usage.
 
-      configureLocalInstance([instance][, options])
-            Validates and configures a local instance for MySQL InnoDB Cluster
-            usage.
-
-            ATTENTION: This function is deprecated and will be removed in a
-                       future release of MySQL Shell, use
-                       dba.configureInstance() instead.
-
       configureReplicaSetInstance([instance][, options])
             Validates and configures an instance for use in an InnoDB
             ReplicaSet.
 
       createCluster(name[, options])
-            Creates a MySQL InnoDB cluster.
+            Creates a MySQL InnoDB Cluster.
 
       createReplicaSet(name[, options])
             Creates a MySQL InnoDB ReplicaSet.
@@ -82,7 +74,7 @@ FUNCTIONS
       dropMetadataSchema(options)
             Drops the Metadata Schema.
 
-      getCluster([name][, options])
+      getCluster([name])
             Returns an object representing a Cluster.
 
       getClusterSet()
@@ -167,14 +159,6 @@ DESCRIPTION
         instance. If this option is given, the configuration file will be
         verified for the expected option values, in addition to the global
         MySQL system variables.
-      - password: The password to get connected to the instance.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
-
-      The connection password may be contained on the instance definition,
-      however, it can be overwritten if it is specified on the options.
 
       The returned descriptive text of the operation result indicates whether
       the instance is valid for InnoDB Cluster usage or not. If not, a table
@@ -194,10 +178,6 @@ DESCRIPTION
       - Update the server variable.
       - Restart the server.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
 //@<OUT> Configure Instance
 NAME
       configureInstance - Validates and configures an instance for MySQL InnoDB
@@ -226,7 +206,6 @@ DESCRIPTION
       - mycnfPath: The path to the MySQL configuration file of the instance.
       - outputMycnfPath: Alternative output path to write the MySQL
         configuration file of the instance.
-      - password: The password to be used on the connection. Deprecated.
       - clusterAdmin: The name of the "cluster administrator" account.
       - clusterAdminPassword: The password for the "cluster administrator"
         account.
@@ -237,23 +216,14 @@ DESCRIPTION
         account.
       - clusterAdminCertSubject: Optional SSL certificate subject for the
         account.
-      - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled. Deprecated and default value is true.
       - restart: boolean value used to indicate that a remote restart of the
         target instance should be performed to finalize the operation.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - applierWorkerThreads: Number of threads used for applying replicated
         transactions. The default value is 4.
 
       If the outputMycnfPath option is used, only that file is updated and
       mycnfPath is treated as read-only.
 
-      The connection password may be contained on the instance definition,
-      however, it can be overwritten if it is specified on the options.
-
       The clusterAdmin must be a standard MySQL account name. It could be
       either an existing account or an account to be created.
 
@@ -273,101 +243,6 @@ DESCRIPTION
         variable.
       - Required Value: the required value for the configuration variable.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The clearReadOnly option will be removed in a future release
-                 and it's no longer needed, super_read_only is automatically
-                 cleared.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
-//@<OUT> Configure Local Instance
-NAME
-      configureLocalInstance - Validates and configures a local instance for
-                               MySQL InnoDB Cluster usage.
-
-SYNTAX
-      dba.configureLocalInstance([instance][, options])
-
-WHERE
-      instance: An instance definition.
-      options: Additional options for the operation.
-
-RETURNS
-      Nothing
-
-DESCRIPTION
-      ATTENTION: This function is deprecated and will be removed in a future
-                 release of MySQL Shell, use dba.configureInstance() instead.
-
-      This function reviews the instance configuration to identify if it is
-      valid for usage in an InnoDB cluster, making configuration changes if
-      necessary.
-
-      The instance definition is the connection data for the instance.
-
-      For additional information on connection data use \? connection.
-
-      The options dictionary may contain the following options:
-
-      - mycnfPath: The path to the MySQL configuration file of the instance.
-      - outputMycnfPath: Alternative output path to write the MySQL
-        configuration file of the instance.
-      - password: The password to be used on the connection. Deprecated.
-      - clusterAdmin: The name of the "cluster administrator" account.
-      - clusterAdminPassword: The password for the "cluster administrator"
-        account.
-      - clusterAdminPasswordExpiration: Password expiration setting for the
-        account. May be set to the number of days for expiration, 'NEVER' to
-        disable expiration and 'DEFAULT' to use the system default.
-      - clusterAdminCertIssuer: Optional SSL certificate issuer for the
-        account.
-      - clusterAdminCertSubject: Optional SSL certificate subject for the
-        account.
-      - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled. Deprecated and default value is true.
-      - restart: boolean value used to indicate that a remote restart of the
-        target instance should be performed to finalize the operation.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
-
-      If the outputMycnfPath option is used, only that file is updated and
-      mycnfPath is treated as read-only.
-
-      The connection password may be contained on the instance definition,
-      however, it can be overwritten if it is specified on the options.
-
-      The clusterAdmin must be a standard MySQL account name. It could be
-      either an existing account or an account to be created.
-
-      The clusterAdminPassword must be specified only if the clusterAdmin
-      account will be created.
-
-      The returned descriptive text of the operation result indicates whether
-      the instance was successfully configured for InnoDB Cluster usage or if
-      it was already valid for InnoDB Cluster usage.
-
-      If the instance was not valid for InnoDB Cluster and interaction is
-      enabled, before configuring the instance a prompt to confirm the changes
-      is presented and a table with the following information:
-
-      - Variable: the invalid configuration variable.
-      - Current Value: the current value for the invalid configuration
-        variable.
-      - Required Value: the required value for the configuration variable.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The clearReadOnly option will be removed in a future release
-                 and it's no longer needed, super_read_only is automatically
-                 cleared.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> Configure ReplicaSet Instance
 NAME
       configureReplicaSetInstance - Validates and configures an instance for
@@ -403,7 +278,6 @@ DESCRIPTION
 
       The options dictionary may contain the following options:
 
-      - password: The password to be used on the connection. Deprecated.
       - clusterAdmin: The name of a "cluster administrator" user to be created.
         The supported format is the standard MySQL account name format.
       - clusterAdminPassword: The password for the "cluster administrator"
@@ -415,18 +289,11 @@ DESCRIPTION
         account.
       - clusterAdminCertSubject: Optional SSL certificate subject for the
         account.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - restart: boolean value used to indicate that a remote restart of the
         target instance should be performed to finalize the operation.
       - applierWorkerThreads: Number of threads used for applying replicated
         transactions. The default value is 4.
 
-      The connection password may be contained on the instance definition,
-      however, it can be overwritten if it is specified on the options.
-
       This function reviews the instance configuration to identify if it is
       valid for usage in replicasets. An exception is thrown if not.
 
@@ -439,67 +306,54 @@ DESCRIPTION
         variable.
       - Required Value: the required value for the configuration variable.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
 //@<OUT> Create Cluster
 NAME
-      createCluster - Creates a MySQL InnoDB cluster.
+      createCluster - Creates a MySQL InnoDB Cluster.
 
 SYNTAX
       dba.createCluster(name[, options])
 
 WHERE
-      name: An identifier for the cluster to be created.
+      name: An identifier for the Cluster to be created.
       options: Dictionary with additional parameters described below.
 
 RETURNS
-      The created cluster object.
+      The created Cluster object.
 
 DESCRIPTION
-      Creates a MySQL InnoDB cluster taking as seed instance the server the
+      Creates a MySQL InnoDB Cluster taking as seed instance the server the
       shell is currently connected to.
 
       The options dictionary can contain the following values:
 
       - disableClone: boolean value used to disable the clone usage on the
-        cluster.
+        Cluster.
       - gtidSetIsComplete: boolean value which indicates whether the GTID set
         of the seed instance corresponds to all transactions executed. Default
         is false.
-      - multiPrimary: boolean value used to define an InnoDB cluster with
+      - multiPrimary: boolean value used to define an InnoDB Cluster with
         multiple writable instances.
       - force: boolean, confirms that the multiPrimary option must be applied
         and/or the operation must proceed even if unmanaged replication
         channels were detected.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
-      - adoptFromGR: boolean value used to create the InnoDB cluster based on
+      - adoptFromGR: boolean value used to create the InnoDB Cluster based on
         existing replication group.
       - memberSslMode: SSL mode for communication channels opened by Group
         Replication from one server to another.
       - memberAuthType: controls the authentication type to use for the
         internal replication accounts.
       - certIssuer: common certificate issuer to use when 'memberAuthType'
-        contains either "CERT_ISSUER" or "CERT_SUBJECT".
+        contains one of the four "CERT_*" values
       - certSubject: instance's certificate subject to use when
-        'memberAuthType' contains "CERT_SUBJECT".
-      - ipWhitelist: The list of hosts allowed to connect to the instance for
-        group replication. Deprecated.
+        'memberAuthType' contains "CERT_SUBJECT" or "CERT_SUBJECT_PASSWORD".
       - ipAllowlist: The list of hosts allowed to connect to the instance for
         group replication. Only valid if communicationStack=XCOM.
       - groupName: string value with the Group Replication group name UUID to
         be used instead of the automatically generated one.
       - localAddress: string value with the Group Replication local address to
         be used instead of the automatically generated one.
-      - groupSeeds: string value with a comma-separated list of the Group
-        Replication peer addresses to be used instead of the automatically
-        generated one. Deprecated and ignored.
       - manualStartOnBoot: boolean (default false). If false, Group Replication
-        in cluster instances will automatically start and rejoin when MySQL
+        in Cluster instances will automatically start and rejoin when MySQL
         starts, otherwise it must be started manually.
       - replicationAllowedHost: string value to use as the host name part of
         internal replication accounts (i.e.
@@ -512,63 +366,57 @@ DESCRIPTION
         primary election on failover.
       - consistency: string value indicating the consistency guarantees that
         the cluster provides.
-      - failoverConsistency: string value indicating the consistency guarantees
-        that the cluster provides.
       - expelTimeout: integer value to define the time period in seconds that
         cluster members should wait for a non-responding member before evicting
         it from the cluster.
       - autoRejoinTries: integer value to define the number of times an
         instance will attempt to rejoin the cluster after being expelled.
-      - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled. Deprecated.
-      - multiMaster: boolean value used to define an InnoDB cluster with
-        multiple writable instances. Deprecated.
-      - communicationStack: The Group Replication protocol stack to be used in
-        the Cluster: XCom (legacy) or MySQL.
+      - communicationStack: The Group Replication communication stack to be
+        used in the Cluster: XCom (legacy) or MySQL.
       - transactionSizeLimit: integer value to configure the maximum
         transaction size in bytes which the Cluster accepts
       - paxosSingleLeader: boolean value used to enable/disable the Group
         Communication engine to operate with a single consensus leader.
 
-      An InnoDB cluster may be setup in two ways:
+      An InnoDB Cluster may be setup in two ways:
 
-      - Single Primary: One member of the cluster allows write operations while
+      - Single Primary: One member of the Cluster allows write operations while
         the rest are read-only secondaries.
-      - Multi Primary: All the members in the cluster allow both read and write
+      - Multi Primary: All the members in the Cluster allow both read and write
         operations.
 
       Note that Multi-Primary mode has limitations about what can be safely
       executed. Make sure to read the MySQL documentation for Group Replication
       and be aware of what is and is not safely executable in such setups.
 
-      By default this function creates a Single Primary cluster. Use the
-      multiPrimary option set to true if a Multi Primary cluster is required.
+      By default this function creates a Single Primary Cluster. Use the
+      multiPrimary option set to true if a Multi Primary Cluster is required.
+
+      The Cluster's name must be non-empty and no greater than 63 characters
+      long. It can only start with an alphanumeric character or with _
+      (underscore), and can only contain alphanumeric, _ ( underscore), .
+      (period), or - (hyphen) characters.
 
       Options
 
-      interactive controls whether prompts are shown for MySQL passwords,
-      confirmations and handling of cases where user feedback may be required.
-      Defaults to true, unless the Shell is started with the --no-wizards
-      option.
-
       disableClone should be set to true if built-in clone support should be
       completely disabled, even in instances where that is supported. Built-in
       clone support is available starting with MySQL 8.0.17 and allows
-      automatically provisioning new cluster members by copying state from an
-      existing cluster member. Note that clone will completely delete all data
-      in the instance being added to the cluster.
+      automatically provisioning new Cluster members by copying state from an
+      existing Cluster member. Note that clone will completely delete all data
+      in the instance being added to the Cluster.
 
       gtidSetIsComplete is used to indicate that GTIDs have been always enabled
-      at the cluster seed instance and that GTID_EXECUTED contains all
+      at the Cluster seed instance and that GTID_EXECUTED contains all
       transactions ever executed. It must be left as false if data was inserted
       or modified while GTIDs were disabled or if RESET MASTER was executed.
-      This flag affects how cluster.addInstance() decides which recovery
+      This flag affects how Cluster.addInstance() decides which recovery
       methods are safe to use. Distributed recovery based on replaying the
       transaction history is only assumed to be safe if the transaction history
-      is known to be complete, otherwise cluster members could end up with
+      is known to be complete, otherwise Cluster members could end up with
       incomplete data sets.
 
-      adoptFromGR allows creating an InnoDB cluster from an existing unmanaged
+      adoptFromGR allows creating an InnoDB Cluster from an existing unmanaged
       Group Replication setup, enabling use of MySQL Router and the shell
       AdminAPI for managing it.
 
@@ -606,6 +454,8 @@ DESCRIPTION
       - CERT_SUBJECT_PASSWORD: combines both "CERT_SUBJECT" and "PASSWORD"
         values.
 
+      If memberAuthType is not specified, "PASSWORD" will be used by default.
+
       When CERT_ISSUER or CERT_SUBJECT are used, the server's own certificate
       is used as its client certificate when authenticating replication
       channels with peer servers. memberSslMode must be at least REQUIRED,
@@ -639,10 +489,6 @@ DESCRIPTION
       stack is 'XCOM'. In case the automatically determined  default port value
       is invalid (> 65535) then an error is thrown.
 
-      The groupSeeds option is deprecated as of MySQL Shell 8.0.28 and is
-      ignored. 'group_replication_group_seeds' is automatically set based on
-      the current topology.
-
       The exitStateAction option supports the following values:
 
       - ABORT_SERVER: if used, the instance shuts itself down if it leaves the
@@ -654,7 +500,8 @@ DESCRIPTION
         it leaves the cluster unintentionally or exhausts its auto-rejoin
         attempts. Requires MySQL 8.0.18 or newer.
 
-      If exitStateAction is not specified READ_ONLY will be used by default.
+      If exitStateAction is not specified, it defaults to OFFLINE_MODE for
+      server versions 8.4.0 or newer, and READ_ONLY otherwise.
 
       The consistency option supports the following values:
 
@@ -664,7 +511,9 @@ DESCRIPTION
       - EVENTUAL: if used, read queries to the new primary are allowed even if
         the backlog isn't applied.
 
-      If consistency is not specified, EVENTUAL will be used by default.
+      If consistency is not specified, it defaults to
+      BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or newer, and
+      EVENTUAL otherwise.
 
       The value for exitStateAction is used to configure how Group Replication
       behaves when a server instance leaves the group unintentionally (for
@@ -678,7 +527,8 @@ DESCRIPTION
       option accepts case-insensitive string values, being the accepted values:
       OFFLINE_MODE (or 2), ABORT_SERVER (or 1) and READ_ONLY (or 0).
 
-      The default value is READ_ONLY.
+      The default value is OFFLINE_MODE for server versions 8.4.0 or newer, and
+      READ_ONLY otherwise.
 
       The value for memberWeight is used to set the Group Replication system
       variable 'group_replication_member_weight'. The memberWeight option
@@ -694,10 +544,20 @@ DESCRIPTION
       When set to BEFORE_ON_PRIMARY_FAILOVER, whenever a primary failover
       happens in single-primary mode (default), new queries (read or write) to
       the newly elected primary that is applying backlog from the old primary,
-      will be hold before execution until the backlog is applied. When set to
-      EVENTUAL, read queries to the new primary are allowed even if the backlog
-      isn't applied but writes will fail (if the backlog isn't applied) due to
-      super-read-only mode being enabled. The client may return old values.
+      will be hold before execution until the backlog is applied. Special care
+      is needed if LOCK / UNLOCK queries are used in a secondary, because the
+      UNLOCK statement can be held. This means that, if the secondary is
+      promoted, and transactions from the primary are being applied that target
+      locked tables, they won't be applied and an explicit UNLOCK will also
+      hold because the secondary needs to finish applying the transactions from
+      the previous primary. See
+      https://dev.mysql.com/doc/refman/en/group-replication-system-variables.html#sysvar_group_replication_consistency
+      for more details.
+
+      When set to EVENTUAL, read queries to the new primary are allowed even if
+      the backlog isn't applied but writes will fail (if the backlog isn't
+      applied) due to super-read-only mode being enabled. The client may return
+      old values.
 
       When set to BEFORE, each transaction (RW or RO) waits until all preceding
       transactions are complete before starting its execution. This ensures
@@ -728,7 +588,8 @@ DESCRIPTION
       accepted values: EVENTUAL (or 0), BEFORE_ON_PRIMARY_FAILOVER (or 1),
       BEFORE (or 2), AFTER (or 3), and BEFORE_AND_AFTER (or 4).
 
-      The default value is EVENTUAL.
+      It defaults to BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or
+      newer, and EVENTUAL otherwise.
 
       The value for expelTimeout is used to set the Group Replication system
       variable 'group_replication_member_expel_timeout' and configure how long
@@ -785,21 +646,6 @@ DESCRIPTION
       The option is available on MySQL 8.0.31 or newer and the default value is
       'OFF'.
 
-      ATTENTION: The clearReadOnly option will be removed in a future release.
-
-      ATTENTION: The multiMaster option will be removed in a future release.
-                 Please use the multiPrimary option instead.
-
-      ATTENTION: The failoverConsistency option will be removed in a future
-                 release. Please use the consistency option instead.
-
-      ATTENTION: The ipWhitelist option will be removed in a future release.
-                 Please use the ipAllowlist option instead.
-
-      ATTENTION: The groupSeeds option will be removed in a future release.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> Create ReplicaSet
 NAME
       createReplicaSet - Creates a MySQL InnoDB ReplicaSet.
@@ -808,11 +654,11 @@ SYNTAX
       dba.createReplicaSet(name[, options])
 
 WHERE
-      name: An identifier for the replicaset to be created.
+      name: An identifier for the ReplicaSet to be created.
       options: Dictionary with additional parameters described below.
 
 RETURNS
-      The created replicaset object.
+      The created ReplicaSet object.
 
 DESCRIPTION
       This function will create a managed ReplicaSet using MySQL asynchronous
@@ -825,15 +671,15 @@ DESCRIPTION
       metadata schema will be initialized there.
 
       New replica instances can be added through the addInstance() function of
-      the returned replicaset object. Status of the instances and their
+      the returned ReplicaSet object. Status of the instances and their
       replication channels can be inspected with status().
 
       InnoDB ReplicaSets
 
-      A replicaset allows managing a GTID-based MySQL replication setup, in a
+      A ReplicaSet allows managing a GTID-based MySQL replication setup, in a
       single PRIMARY/multiple SECONDARY topology.
 
-      A replicaset has several limitations compared to a InnoDB cluster and
+      A ReplicaSet has several limitations compared to a InnoDB cluster and
       thus, it is recommended that InnoDB clusters be preferred unless not
       possible. Generally, a ReplicaSet on its own does not provide High
       Availability. Among its limitations are:
@@ -852,18 +698,23 @@ DESCRIPTION
         Replication
       - GTIDs required
       - Replication filters are not allowed
-      - All instances in the replicaset must be managed
+      - All instances in the ReplicaSet must be managed
       - Unmanaged replication channels are not allowed in any instance
 
+      The ReplicaSet's name must be non-empty and no greater than 63 characters
+      long. It can only start with an alphanumeric character or with _
+      (underscore), and can only contain alphanumeric, _ ( underscore), .
+      (period), or - ( hyphen) characters.
+
       Adopting an Existing Topology
 
       Existing asynchronous setups can be managed by calling this function with
       the adoptFromAR option. The topology will be automatically scanned and
       validated, starting from the instance the shell is connected to, and all
       instances that are part of the topology will be automatically added to
-      the replicaset.
+      the ReplicaSet.
 
-      The only changes made by this function to an adopted replicaset are the
+      The only changes made by this function to an adopted ReplicaSet are the
       creation of the metadata schema. Existing replication channels will not
       be changed during adoption, although they will be changed during PRIMARY
       switch operations.
@@ -879,7 +730,7 @@ DESCRIPTION
 
       The options dictionary can contain the following values:
 
-      - adoptFromAR: boolean value used to create the replicaset based on an
+      - adoptFromAR: boolean value used to create the ReplicaSet based on an
         existing asynchronous replication setup.
       - instanceLabel: string a name to identify the target instance. Defaults
         to hostname:port
@@ -893,18 +744,14 @@ DESCRIPTION
         internal replication accounts (i.e. 'mysql_innodb_rs_###'@'hostname').
         Default is %. It must be possible for any member of the ReplicaSet to
         connect to any other member using accounts with this hostname value.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - memberAuthType: controls the authentication type to use for the
         internal replication accounts.
       - certIssuer: common certificate issuer to use when 'memberAuthType'
-        contains either "CERT_ISSUER" or "CERT_SUBJECT".
+        contains one of the four "CERT_*" values
       - certSubject: instance's certificate subject to use when
-        'memberAuthType' contains "CERT_SUBJECT".
+        'memberAuthType' contains "CERT_SUBJECT" or "CERT_SUBJECT_PASSWORD".
       - replicationSslMode: SSL mode to use to configure the asynchronous
-        replication channels of the replicaset.
+        replication channels of the ReplicaSet.
 
       The replicationSslMode option supports the following values:
 
@@ -933,14 +780,14 @@ DESCRIPTION
       - CERT_SUBJECT_PASSWORD: combines both "CERT_SUBJECT" and "PASSWORD"
         values.
 
+      If memberAuthType is not specified, "PASSWORD" will be used by default.
+
       When CERT_ISSUER or CERT_SUBJECT are used, the server's own certificate
       is used as its client certificate when authenticating replication
       channels with peer servers. replicationSslMode must be at least REQUIRED,
       although VERIFY_CA or VERIFY_IDENTITY are recommended for additional
       security.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> Delete Sandbox
 NAME
       deleteSandboxInstance - Deletes an existing MySQL Server instance on
@@ -1034,23 +881,16 @@ DESCRIPTION
       The options dictionary may contain the following options:
 
       - force: boolean, confirms that the drop operation must be executed.
-      - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled. Deprecated and default value is true.
-
-      ATTENTION: The clearReadOnly option will be removed in a future release
-                 and it's no longer needed, super_read_only is automatically
-                 cleared.
 
 //@<OUT> Get Cluster
 NAME
       getCluster - Returns an object representing a Cluster.
 
 SYNTAX
-      dba.getCluster([name][, options])
+      dba.getCluster([name])
 
 WHERE
       name: Parameter to specify the name of the Cluster to be returned.
-      options: Dictionary with additional options.
 
 RETURNS
       The Cluster object identified by the given name or the default Cluster.
@@ -1062,13 +902,6 @@ DESCRIPTION
       If name is specified, and no Cluster with the indicated name is found, an
       error will be raised.
 
-      The options dictionary may contain the following attributes:
-
-      - connectToPrimary: boolean value used to indicate if Shell should
-        automatically connect to the primary member of the Cluster or not.
-        Deprecated and ignored, Shell will attempt to connect to the primary by
-        default and fallback to a secondary when not possible.
-
 //@<OUT> Get ReplicaSet
 NAME
       getReplicaSet - Returns an object representing a ReplicaSet.
@@ -1165,11 +998,6 @@ RETURNS
 DESCRIPTION
       The options dictionary can contain the next values:
 
-      - user: The user used for the instances sessions required operations.
-      - password: The password used for the instances sessions required
-        operations.
-      - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled.
       - force: boolean value to indicate that the operation must be executed
         even if some members of the Cluster cannot be reached, or the primary
         instance selected has a diverging or lower GTID_SET.
@@ -1178,13 +1006,13 @@ DESCRIPTION
         will be thrown when finished.
       - primary: Instance definition representing the instance that must be
         selected as the primary.
-      - switchCommunicationStack: The Group Replication protocol stack to be
-        used by the Cluster after the reboot.
-      - ipAllowList: The list of hosts allowed to connect to the instance for
-        Group Replication traffic when using the 'XCOM' protocol stack.
+      - switchCommunicationStack: The Group Replication communication stack to
+        be used by the Cluster after the reboot.
+      - ipAllowlist: The list of hosts allowed to connect to the instance for
+        Group Replication traffic when using the 'XCOM' communication stack.
       - localAddress: string value with the Group Replication local address to
         be used instead of the automatically generated one when using the
-        'XCOM' protocol stack.
+        'XCOM' communication stack.
       - timeout: integer value with the maximum number of seconds to wait for
         pending transactions to be applied in each instance of the cluster
         (default value is retrieved from the 'dba.gtidWaitTimeout' shell
@@ -1242,12 +1070,6 @@ DESCRIPTION
       The option is used to switch the value of paxosSingleLeader previously in
       use by the Cluster, to either enable or disable it.
 
-      ATTENTION: The clearReadOnly option will be removed in a future release.
-
-      ATTENTION: The user option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
       This function reboots a cluster from complete outage. It obtains the
       Cluster information from the instance MySQL Shell is connected to and
       uses the most up-to-date instance in regards to transactions as new seed
@@ -1261,12 +1083,6 @@ DESCRIPTION
 
       If name is not specified, the default cluster will be returned.
 
-      NOTE: The user and password options are no longer used, the connection
-            data is taken from the active shell session.
-
-      NOTE: The clearReadOnly option is no longer used, super_read_only is
-            automatically cleared.
-
 //@<OUT> Start Sandbox
 NAME
       startSandboxInstance - Starts an existing MySQL Server instance on
@@ -1343,19 +1159,8 @@ DESCRIPTION
 
       The options dictionary accepts the following attributes:
 
-      - dryRun: boolean value used to enable a dry run of the upgrade process.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
-
-      If dryRun is used, the function will determine whether a metadata upgrade
-      or restore is required and inform the user without actually executing the
-      operation.
-
-      The interactive option can be used to explicitly enable or disable the
-      interactive prompts that help the user through te upgrade process. The
-      default value is equal to MySQL Shell wizard mode.
+      - dryRun: boolean, if true all validations and steps to run the upgrade
+        process are executed but no changes are actually made.
 
       The Upgrade Process
 
@@ -1378,5 +1183,3 @@ DESCRIPTION
       If the installed metadata is not available because a previous call to
       this function ended unexpectedly, this function will restore the metadata
       to the state it was before the failed upgrade operation.
-
-      ATTENTION: The interactive option will be removed in a future release.
