@@ -5,7 +5,7 @@
 ||An open session is required to perform this operation.
 
 //@<OUT> FR_1 Configure instance not valid for InnoDB cluster {VER(>=8.0.11)}
-Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
@@ -48,7 +48,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -58,6 +58,15 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 NOTE: Please use the dba.configureInstance() command to repair these issues.
@@ -183,7 +192,7 @@ NOTE: Please use the dba.configureInstance() command to repair these issues.
     "status": "error"
 }
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 {
     "config_errors": [
         {
@@ -214,9 +223,32 @@ NOTE: Please use the dba.configureInstance() command to repair these issues.
     "status": "error"
 }
 ?{}
-WARNING: The interactive option is deprecated and will be removed in a future release.
-
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+?{VER(>=8.3.0)}
+{
+    "config_errors": [
+        {
+            "action": "server_update+restart",
+            "current": "OFF",
+            "option": "enforce_gtid_consistency",
+            "required": "ON"
+        },
+        {
+            "action": "server_update+restart",
+            "current": "OFF",
+            "option": "gtid_mode",
+            "required": "ON"
+        },
+        {
+            "action": "server_update+restart",
+            "current": "1",
+            "option": "server_id",
+            "required": "<unique ID>"
+        }
+    ],
+    "status": "error"
+}
+?{}
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 ?{VER(>=8.0.23)}
@@ -258,7 +290,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -268,16 +300,25 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 Configuring instance...
-?{((VER(>=8.0.35) && VER(<8.1.0)) || VER(>=8.2.0)) && !__replaying}
+?{((VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))) && !__replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
-Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
@@ -287,7 +328,7 @@ No incompatible tables detected
 Checking instance configuration...
 Instance configuration is compatible with InnoDB cluster
 
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.
 
 {
     "status": "ok"
@@ -305,8 +346,8 @@ The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in
 ||Unable to update configuration
 
 //@# FR1.1_2 Configure instance using dba.configureInstance() with variable that cannot remotely persisted {VER(>=8.0.11)}
-|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.|
-|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.|
+|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.|
+|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.|
 
 //@ FR1.1 TEARDOWN {VER(>=8.0.11)}
 ||
@@ -319,7 +360,7 @@ The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in
 ||Unable to update configuration
 
 //@<OUT> FR2_2 - Configure local instance using dba.configureInstance() with 'persisted-globals-load' set to 'OFF' with cnf file path {VER(>=8.0.11)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 ?{VER(>=8.0.23)}
@@ -347,7 +388,7 @@ Some variables need to be changed, but cannot be done dynamically on the server:
 NOTE: persisted_globals_load option is OFF
 Remote configuration of the instance is not possible because options changed with SET PERSIST will not be loaded, unless 'persisted_globals_load' is set to ON.
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(>=8.0.21) && VER(<8.0.23)}
@@ -394,7 +435,7 @@ NOTE: MySQL server needs to be restarted for configuration changes to take effec
 | transaction_write_set_extraction       | <not set>     | XXHASH64       | Update the config file                         |
 +----------------------------------------+---------------+----------------+------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                           |
 +----------------------------------------+---------------+----------------+------------------------------------------------+
@@ -409,16 +450,28 @@ NOTE: MySQL server needs to be restarted for configuration changes to take effec
 | transaction_write_set_extraction       | <not set>     | XXHASH64       | Update the config file                         |
 +----------------------------------------+---------------+----------------+------------------------------------------------+
 ?{}
+?{VER(>=8.4.0)}
++-------------------------------+---------------+----------------+-----------------------------------------------+
+| Variable                      | Current Value | Required Value | Note                                          |
++-------------------------------+---------------+----------------+-----------------------------------------------+
+| binlog_format                 | <not set>     | ROW            | Update the config file                        |
+| enforce_gtid_consistency      | OFF           | ON             | Update the config file and restart the server |
+| gtid_mode                     | OFF           | ON             | Update the config file and restart the server |
+| replica_preserve_commit_order | <not set>     | ON             | Update the config file                        |
+| report_port                   | <not set>     | <<<__mysql_sandbox_port1>>>           | Update the config file                        |
+| server_id                     | 1             | <unique ID>    | Update the config file and restart the server |
++-------------------------------+---------------+----------------+-----------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server: set persist support is disabled. Enable it or provide an option file.
 NOTE: persisted_globals_load option is OFF
 Remote configuration of the instance is not possible because options changed with SET PERSIST will not be loaded, unless 'persisted_globals_load' is set to ON.
 Configuring instance...
-?{((VER(>=8.0.35) && VER(<8.1.0)) || VER(>=8.2.0)) && !__replaying}
+?{((VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))) && !__replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 
 //@ FR2_2 TEARDOWN {VER(>=8.0.11)}
@@ -428,7 +481,7 @@ NOTE: MySQL server needs to be restarted for configuration changes to take effec
 ||
 
 //@<OUT>FR3.1_1 - Configure local instance with 'persisted-globals-load' set to 'OFF' {VER(<8.0.11)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
@@ -451,10 +504,10 @@ NOTE: Some configuration options need to be fixed:
 
 Some variables need to be changed, but cannot be done dynamically on the server: an option file is required.
 Do you want to perform the required configuration changes? [y/n]: Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 WARNING: Support for AdminAPI operations in MySQL version 5.7 is deprecated and will be removed in a future release of MySQL Shell
-Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
@@ -488,11 +541,11 @@ NOTE: Please use the dba.configureInstance() command to repair these issues.
 ||
 
 //@# FR3.2_1 - Configure local instance with 'persisted-globals-load' set to 'OFF' providing mycnfPath {VER(<8.0.11)}
-|Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...|
-|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.|
+|Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...|
+|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.|
 |NOTE: MySQL server needs to be restarted for configuration changes to take effect.|
 
-|Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...|
+|Validating local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...|
 |Please use the dba.configureInstance() command to repair these issues.|
 
 //@ FR3.2_1 TEARDOWN {VER(<8.0.11)}
@@ -502,12 +555,12 @@ NOTE: Please use the dba.configureInstance() command to repair these issues.
 ||
 
 //@# FR3.3_1 - Configure local instance that does not require changes {VER(<8.0.11)}
-|Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...|
+|Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...|
 |1) Create remotely usable account for 'root' with same grants and password|
-|2) Create a new admin account for InnoDB cluster with minimal required grants|
+|2) Create a new admin account for InnoDB Cluster with minimal required grants|
 |3) Ignore and continue|
 |4) Cancel|
-|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.|
+|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.|
 
 //@ FR3.3_1 TEARDOWN {VER(<8.0.11)}
 ||
@@ -516,14 +569,14 @@ NOTE: Please use the dba.configureInstance() command to repair these issues.
 ||
 
 //@<OUT> FR5 Configure instance not valid for InnoDB cluster, with interaction enabled {VER(>=8.0.11)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
 ERROR: User 'root' can only connect from 'localhost'. New account(s) with proper source address specification to allow remote connection from all instances must be created to manage the cluster.
 
 1) Create remotely usable account for 'root' with same grants and password
-2) Create a new admin account for InnoDB cluster with minimal required grants
+2) Create a new admin account for InnoDB Cluster with minimal required grants
 3) Ignore and continue
 4) Cancel
 
@@ -566,7 +619,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -576,14 +629,23 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 Do you want to perform the required configuration changes? [y/n]: Do you want to restart the instance after configuring it? [y/n]: Configuring instance...
-?{((VER(>=8.0.35) && VER(<8.1.0)) || VER(>=8.2.0)) && !__replaying}
+?{((VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))) && !__replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 
 //@ FR5 TEARDOWN {VER(>=8.0.11)}
@@ -608,7 +670,7 @@ NOTE: MySQL server needs to be restarted for configuration changes to take effec
 ||Access denied for user 'root'@'localhost' (using password: NO) (MySQL Error 1045)
 
 //@<OUT> ET_10 - Call dba.configuereInstance() with interactive flag set to true and using clusterAdmin {VER(>=8.0.11)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 Assuming full account name 'clusterAdminAccount'@'%' for clusterAdminAccount
@@ -651,7 +713,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -661,6 +723,15 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 Do you want to perform the required configuration changes? [y/n]: Do you want to restart the instance after configuring it? [y/n]:
@@ -668,14 +739,14 @@ Creating user clusterAdminAccount@%.
 Account clusterAdminAccount@% was successfully created.
 
 Configuring instance...
-?{((VER(>=8.0.35) && VER(<8.1.0)) || VER(>=8.2.0)) && !__replaying}
+?{((VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))) && !__replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 
 //@<OUT> ET_12 - Call dba.configuereInstance() with interactive flag set to true, clusterAdmin option and super_read_only=1 {VER(>=8.0.11)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 Assuming full account name 'newClusterAdminAccount'@'%' for newClusterAdminAccount
@@ -701,17 +772,5 @@ Account newClusterAdminAccount@% was successfully created.
 
 Enabling super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
-
-//@ ET_12_alt - Super read-only enabled and 'clearReadOnly' is set
-||
-
-//@ ET_12_alt - Super read-only enabled and 'clearReadOnly' is set 5.7
-||
-
-//@ ET_13 - Call dba.configuereInstance() with interactive flag set to false, clusterAdmin option and super_read_only=1 {VER(>=8.0.11)}
-||
-
-//@ ET TEARDOWN
-||
