@@ -227,13 +227,13 @@ This instance reports its own address as ${hostname}:${__mysql_sandbox_port4}
 
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '${hostname}:${__mysql_sandbox_port4}1'. Use the localAddress option to override.
-
+[[*]]
 * Checking connectivity and SSL configuration...
 
 
 * Checking transaction state of the instance...
 
-NOTE: The target instance '${hostname}:${__mysql_sandbox_port4}' has not been pre-provisioned (GTID set is empty). The Shell is unable to decide whether replication can completely recover its state.
+NOTE: The target instance '${hostname}:${__mysql_sandbox_port4}' has not been pre-provisioned (GTID set is empty).
 
 Incremental state recovery selected through the recoveryMethod option
 
