@@ -663,7 +663,7 @@ TEST_F(Shell_cli_operation_test, local_dict) {
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(1, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
   }
   {
@@ -684,7 +684,7 @@ TEST_F(Shell_cli_operation_test, local_dict) {
     // This no longer crashes as { and } are simply ignored
     prepare();
     EXPECT_EQ(1, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
   }
   {
@@ -718,7 +718,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(1, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
     EXPECT_EQ("required", m_argument_list.map_at(0)->get_string("ssl-mode"));
     EXPECT_EQ("zstd",
@@ -743,7 +743,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(2, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     auto co = m_argument_list.map_at(0);
     // a connection options dictionary
     EXPECT_EQ(3306, co->get_int("port"));
@@ -752,7 +752,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("root", co->get_string("user"));
 
     // not a connection options dictionary
-    ASSERT_TRUE(m_argument_list[1].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[1].get_type() == Value_type::Map);
     EXPECT_EQ("/whatever/path",
               m_argument_list.map_at(1)->get_string("configPath"));
   }
@@ -769,7 +769,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(2, m_argument_list.size());
     EXPECT_EQ(shcore::Value::Null(), m_argument_list[0]);
-    ASSERT_TRUE(m_argument_list[1].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[1].get_type() == Value_type::Map);
     auto co = m_argument_list.map_at(1);
     // a connection options dictionary
     EXPECT_EQ("JSON", co->get_string("outputFormat"));
@@ -852,6 +852,16 @@ TEST_F(Shell_cli_operation_test, integration_test) {
                     {"--", "util", "check-for-server-upgrade", uri.c_str()}, "",
                     env));
   MY_EXPECT_STDOUT_CONTAINS("will now be checked for compatibility issues");
+  MY_EXPECT_STDOUT_CONTAINS("To check for a different target server version");
+  output_handler.wipe_all();
+
+  EXPECT_NE(10,
+            testutil->call_mysqlsh_c({"--", "util", "check-for-server-upgrade",
+                                      uri.c_str(), "--target-version=8.3.0"},
+                                     "", env));
+  MY_EXPECT_STDOUT_CONTAINS("will now be checked for compatibility issues");
+  MY_EXPECT_STDOUT_NOT_CONTAINS(
+      "To check for a different target server version");
   output_handler.wipe_all();
 
   MY_EXPECT_EQ_OR_DUMP(
@@ -929,6 +939,21 @@ TEST_F(Shell_cli_operation_test, test_invalid_cli_operations) {
   }
 }
 
+TEST_F(Shell_cli_operation_test, bug34887426_special_chars) {
+  // In:
+  //  mysqlsh -- util import-table ... --linesTerminatedBy=$'\n'
+  // $'\n' is expanded by bash to a newline literal
+  std::vector<std::string> env{"MYSQLSH_TERM_COLOR_MODE=nocolor"};
+
+  testutil->call_mysqlsh_c({_uri.c_str(), "--", "util", "import-table",
+                            "/bad/file", "--linesTerminatedBy=\n"},
+                           "", env);
+
+  MY_EXPECT_STDOUT_NOT_CONTAINS("The following option is invalid");
+
+  output_handler.wipe_all();
+}
+
 #define TEST_API_CLI_OPTIONS(OPTIONS, ...) \
   test<OPTIONS>(__FILE__, __LINE__, __VA_ARGS__)
 
@@ -1019,7 +1044,7 @@ class Test_cli_integration_api_options : public Shell_cli_operation_test {
           // Small exception if the actual argument is an array, in that case
           // the expected should contain all the values until named ones are
           // found
-          if (actual.type == shcore::Array) {
+          if (actual.get_type() == shcore::Array) {
             auto array = shcore::make_array();
             while (index < last_positional) {
               array->push_back(positional_arguments.at(index++));
@@ -1059,7 +1084,7 @@ class Test_cli_integration_api_options : public Shell_cli_operation_test {
 
 TEST_F(Test_cli_integration_api_options, all) {
   /** The UTILS Object **/
-  TEST_API_CLI_OPTIONS(mysqlsh::Upgrade_check_options, "util",
+  TEST_API_CLI_OPTIONS(mysqlsh::upgrade_checker::Upgrade_check_options, "util",
                        "check-for-server-upgrade", "dummy_uri@localhost");
 
   TEST_API_CLI_OPTIONS(mysqlsh::import_table::Import_table_option_pack, "util",
